Class EnvironmentProperties

java.lang.Object
org.refcodes.properties.EnvironmentProperties
All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String,String>

public class EnvironmentProperties extends Object implements ImmutableProperties
Extension of the ImmutableProperties type overwriting methods in order to access the operating system's environment variables as of env on Linux or Unix shells or set on Windows machines (e.g."set JAVA_HOME=/opt/java9"). The keys are transformed to an environment variable by removing a prefixed "/" path delimiter (as of ImmutableProperties.getDelimiter() and converting all other path delimiters "/" to the environment variable's (de facto standard) separator "_". If accessing failed, then the upper case version of the so transformed key is probed. Accessing an environment variable "JAVA_HOME" would be done with the path "/java/home".