Interface ImmutableProperties

All Superinterfaces:
AnnotatorAccessor, Containable, DelimiterAccessor, EmptyAccessor, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String,String>, TypeAccessor<String>
All Known Subinterfaces:
ImmutableProperties.MutableProperties, ImmutablePropertiesPrecedence, ImmutablePropertiesPrecedence.MutablePropertiesPrecedence, ImmutableResourceProperties, ImmutableResourceProperties.MutableResoureProperties, ImmutableScheduledResourceProperties, ImmutableScheduledResourceProperties.ScheduledMuableResourceProperties, ImmutableStrictProperties, ImmutableStrictProperties.MutableStrictProperties, ProfileProperties, Properties, PropertiesPrecedence, ResourceProperties, ScheduledResourceProperties, StrictProperties
All Known Implementing Classes:
AbstractImmutablePropertiesDecorator, AbstractImmutableResourcePropertiesDecorator, AbstractPropertiesDecorator, AbstractResourceProperties, AbstractResourcePropertiesDecorator, ArgsProperties, EnvironmentProperties, ImmutablePropertiesPrecedenceComposite, ImmutableScheduledResourcePropertiesDecorator, ImmutableStrictPropertiesDecorator, JavaProperties, JsonProperties, MapImmutableProperties, MapImmutableProperties.Builder, MapProperties, NormalizedPropertiesDecorator, PolyglotProperties, ProfilePropertiesDecorator, ProfilePropertiesProjection, PropertiesPrecedenceComposite, ScheduledResourcePropertiesDecorator, StrictPropertiesDecorator, SystemProperties, TomlProperties, UnmodifyableProperties, UnmodifyableResourceProperties, XmlProperties, YamlProperties

public interface ImmutableProperties extends ImmutableCanonicalTable
The ImmutableProperties are a https://www.metacodes.proization of the ImmutableTable. ImmutableProperties represent a collection of String key and String value pairs as properties usually occur in pure text form, to be converted to the required data types. For this reason, the ImmutableProperties interface provides additional conversion methods.