Interface ImmutableProperties.MutableProperties
- All Superinterfaces:
AnnotatorAccessor, Clearable, Containable, DelimiterAccessor, EmptyAccessor, ImmutableCanonicalTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutableInterOperableTable.MutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutablePathTable.MutablePathTable<String>, ImmutableProperties, ImmutableTable<String,String>, ImmutableTable.MutableTable<String, String>, Keys<String, String>, Keys.MutableKeys<String, String>, Keys.MutableValues<String, String>, Map<String, String>, TypeAccessor<String>
- All Known Subinterfaces:
ImmutableResourceProperties.MutableResoureProperties, ImmutableScheduledResourceProperties.ScheduledMuableResourceProperties, ImmutableStrictProperties.MutableStrictProperties, Properties, ResourceProperties, ScheduledResourceProperties, StrictProperties
- All Known Implementing Classes:
AbstractPropertiesDecorator, AbstractResourceProperties, AbstractResourcePropertiesDecorator, JavaProperties, JsonProperties, MapImmutableProperties.Builder, MapProperties, PolyglotProperties, ScheduledResourcePropertiesDecorator, StrictPropertiesDecorator, TomlProperties, XmlProperties, YamlProperties
- Enclosing interface:
ImmutableProperties
public static interface ImmutableProperties.MutableProperties
extends ImmutableProperties, ImmutableCanonicalTable.MutableCanonicalTable
The interface
ImmutableProperties.MutableProperties defines "dirty" methods allowing
to modify ("mutate") the properties.-
Nested Class Summary
Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
Fields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface ImmutableProperties
DEFAULT_COMMENT -
Method Summary
Modifier and TypeMethodDescriptiondefault booleancontainsValue(Object value) default Stringdefault voidinsert(ImmutableProperties aFrom) Method to semantically emphasize that we support our own types.default voidinsert(Properties aFrom) Method to semantically emphasize that we support our own types.default voidinsertBetween(String aToPath, ImmutableProperties aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidinsertFrom(ImmutableProperties aFrom, String aFromPath) Method to semantically emphasize that we support our own types.default voidinsertTo(String aToPath, ImmutableProperties aFrom) Method to semantically emphasize that we support our own types.default voiddefault voidputAll(Properties aProperties) This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.default voidputAll(ImmutableProperties aProperties) This method inserts all elements (key/value-pairs) found in the providedImmutablePropertiesinstances of interoperability reasons.default Propertiesdefault PropertiesputDirAt(int aIndex, ImmutablePathTable<String> aDir) default Propertiesdefault PropertiesputDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) default Propertiesdefault PropertiesputDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) default Propertiesdefault PropertiesputDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) default Propertiesdefault PropertiesputDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) default PropertiesputDirAt(Collection<?> aPathElements, int aIndex, Object aDir) default PropertiesputDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) default Propertiesdefault Propertiesdefault Propertiesdefault Propertiesdefault PropertiesremoveAll(Collection<?> aPathQueryElemments) default Propertiesdefault PropertiesremoveDirAt(int aIndex) default PropertiesremoveDirAt(Object[] aPathElements, int aIndex) default PropertiesremoveDirAt(Object aPath, int aIndex) default PropertiesremoveDirAt(String[] aPathElements, int aIndex) default PropertiesremoveDirAt(String aPath, int aIndex) default PropertiesremoveFrom(Object aPath) default PropertiesremoveFrom(Object... aPathElements) default PropertiesremoveFrom(String aPath) default PropertiesremoveFrom(String... aPathElements) default PropertiesremovePaths(String... aPaths) default PropertiesremovePaths(Collection<?> aPaths) Methods inherited from interface Containable
sizeMethods inherited from interface EmptyAccessor
isEmptyMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface ImmutableCanonicalTable.MutableCanonicalTable
insert, insertBetween, insertFrom, insertTo, put, put, put, put, putAll, removeFromMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutableInterOperableTable.MutableInterOperableTable
insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutablePathTable.MutablePathTable
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface ImmutableProperties
getAnnotator, getDelimiter, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveToMethods inherited from interface ImmutableTable.MutableTable
putMethods inherited from interface Keys.MutableValues
putMethods inherited from interface Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Method Details
-
containsValue
- Specified by:
containsValuein interfaceImmutableCanonicalTable- Specified by:
containsValuein interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
containsValuein interfaceImmutableInterOperableTable.MutableInterOperableTable<String>- Specified by:
containsValuein interfaceImmutableProperties- Specified by:
containsValuein interfaceKeys<String,String> - Specified by:
containsValuein interfaceMap<String,String>
-
delete
-
insert
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aFrom- TheImmutablePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.
-
insert
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insert(Object).- Parameters:
aFrom- TheImmutablePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.
-
insertBetween
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertBetween(String, Object, String).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheImmutablePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertFrom
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertFrom(Object, String).- Parameters:
aFrom- TheImmutablePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertTo
Method to semantically emphasize that we support our own types. Actually delegates toImmutablePathTable.MutablePathTable.insertTo(String, Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- TheImmutablePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.
-
putAll
This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.- Specified by:
putAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Parameters:
aProperties- APropertiescontaining the key/value-pairs to be inserted.
-
putAll
-
putAll
This method inserts all elements (key/value-pairs) found in the providedImmutablePropertiesinstances of interoperability reasons.- Parameters:
aProperties- AImmutablePropertiescontaining the key/value pairs to be inserted.
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
default Properties putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) - Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
putDirAt
- Specified by:
putDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
putDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeAll
- Specified by:
removeAllin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeAllin interfaceImmutablePathTable.MutablePathTable<String>
-
removeDirAt
- Specified by:
removeDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeDirAt
- Specified by:
removeDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeDirAt
- Specified by:
removeDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeDirAt
- Specified by:
removeDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeDirAt
- Specified by:
removeDirAtin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeDirAtin interfaceImmutablePathTable.MutablePathTable<String>
-
removeFrom
- Specified by:
removeFromin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<String>
-
removeFrom
- Specified by:
removeFromin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<String>
-
removeFrom
- Specified by:
removeFromin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<String>
-
removeFrom
- Specified by:
removeFromin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removeFromin interfaceImmutablePathTable.MutablePathTable<String>
-
removePaths
- Specified by:
removePathsin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removePathsin interfaceImmutablePathTable.MutablePathTable<String>
-
removePaths
- Specified by:
removePathsin interfaceImmutableCanonicalTable.MutableCanonicalTable- Specified by:
removePathsin interfaceImmutablePathTable.MutablePathTable<String>
-