Interface ImmutablePropertiesPrecedence

All Superinterfaces:
AnnotatorAccessor, Containable, DelimiterAccessor, EmptyAccessor, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableProperties, ImmutableTable<String,String>, Keys<String,String>, TypeAccessor<String>
All Known Subinterfaces:
ImmutablePropertiesPrecedence.MutablePropertiesPrecedence, PropertiesPrecedence
All Known Implementing Classes:
ImmutablePropertiesPrecedenceComposite, PropertiesPrecedenceComposite

public interface ImmutablePropertiesPrecedence extends ImmutableProperties
Defines a meta-interface in order to retrieve properties from various different properties sources (ImmutableProperties instances) by querying all the herein contained ImmutableProperties instances in the order of them being added. Queried properties of the first ImmutableProperties instance containing them are returned. ImmutableProperties instances before have a higher precedence than the instances added next.