Interface ImmutableResourceProperties

All Superinterfaces:
AnnotatorAccessor, Containable, DelimiterAccessor, EmptyAccessor, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableProperties, ImmutableTable<String,String>, Keys<String,String>, TypeAccessor<String>
All Known Subinterfaces:
ImmutableResourceProperties.MutableResoureProperties, ImmutableScheduledResourceProperties, ImmutableScheduledResourceProperties.ScheduledMuableResourceProperties, ResourceProperties, ScheduledResourceProperties
All Known Implementing Classes:
AbstractImmutableResourcePropertiesDecorator, AbstractResourceProperties, AbstractResourcePropertiesDecorator, ImmutableScheduledResourcePropertiesDecorator, JavaProperties, JsonProperties, PolyglotProperties, ScheduledResourcePropertiesDecorator, TomlProperties, UnmodifyableResourceProperties, XmlProperties, YamlProperties

public interface ImmutableResourceProperties extends ImmutableProperties
The ImmutableResourceProperties are a https://www.metacodes.proization of the ImmutableTable. ImmutableProperties represent a collection of String key and String value pairs as properties usually occur in pure text form, to be converted to the required data types. For this reason, the ImmutableResourceProperties interface provides additional conversion methods. When parsing properties from notations which do not support nodes to have values as well as child elements, then please support one of the identifiers contained in the THIS_ATTRIBUTES array.