Module org.refcodes.properties
Package org.refcodes.properties
Class JavaProperties.JavaPropertiesFactory
- java.lang.Object
-
- org.refcodes.properties.JavaProperties.JavaPropertiesFactory
-
- All Implemented Interfaces:
org.refcodes.mixin.FilenameSuffixesAccessor,ResourcePropertiesFactory
- Enclosing class:
- JavaProperties
public static class JavaProperties.JavaPropertiesFactory extends Object implements ResourcePropertiesFactory
TheJavaProperties.JavaPropertiesFactoryrepresents aResourcePropertiesFactorycreating instances of typeJavaProperties.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.FilenameSuffixesAccessor
org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesBuilder<B extends org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesBuilder<B>>, org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesMutator, org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesProperty
-
Nested classes/interfaces inherited from interface org.refcodes.properties.ResourcePropertiesFactory
ResourcePropertiesFactory.ResourcePropertiesBuilderFactory
-
-
Constructor Summary
Constructors Constructor Description JavaPropertiesFactory()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description String[]getFilenameSuffixes()ResourcePropertiestoProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads or seeks the properties from the givenFile.ResourcePropertiestoProperties(InputStream aInputStream, char... aDelimiters)Reads the properties from the givenInputStream.ResourcePropertiestoProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the properties from the given file's path.ResourcePropertiestoProperties(Object aObj)Create aResourcePropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.ResourcePropertiestoProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the properties from the given file's path.ResourcePropertiestoProperties(URL aUrl, char... aDelimiters)Loads the properties from the givenURL.ResourcePropertiestoProperties(Map<?,?> aProperties)Create aResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarationsResourcePropertiestoProperties(Properties aProperties)Create aResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarationsResourcePropertiestoProperties(Properties.PropertiesBuilder aProperties)Create aResourcePropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.properties.ResourcePropertiesFactory
toProperties, toProperties, toProperties, toProperties, toProperties, toProperties, toProperties, toProperties, toProperties, toProperties, toProperties
-
-
-
-
Method Detail
-
getFilenameSuffixes
public String[] getFilenameSuffixes()
- Specified by:
getFilenameSuffixesin interfaceorg.refcodes.mixin.FilenameSuffixesAccessor
-
toProperties
public ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads or seeks the properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(InputStream aInputStream, char... aDelimiters) throws IOException, ParseException
Reads the properties from the givenInputStream.- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(Map<?,?> aProperties)
Create aResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
public ResourceProperties toProperties(Object aObj)
Create aResourcePropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aObj- The object from which the elements are to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
public ResourceProperties toProperties(Properties aProperties)
Create aResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
public ResourceProperties toProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(URL aUrl, char... aDelimiters) throws IOException, ParseException
Loads the properties from the givenURL.- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aUrl- TheURLfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(Properties.PropertiesBuilder aProperties)
Create aResourcePropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
-