Class JavaPropertiesFactory
java.lang.Object
org.refcodes.properties.JavaPropertiesFactory
- All Implemented Interfaces:
FilenameSuffixesAccessor, ImmutableResourcePropertiesFactory, ResourcePropertiesFactory
The
JavaPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
JavaProperties.-
Nested Class Summary
Nested classes/interfaces inherited from interface FilenameSuffixesAccessor
FilenameSuffixesAccessor.FilenameSuffixesBuilder<B>, FilenameSuffixesAccessor.FilenameSuffixesMutator, FilenameSuffixesAccessor.FilenameSuffixesProperty -
Constructor Summary
ConstructorsConstructorDescriptionConstructs anXmlCanonicalTableFactoryfor creatingXmlPropertiesinstances.JavaPropertiesFactory(DocumentOptions aDocumentOptions) Constructs anXmlCanonicalTableFactoryfor creatingXmlPropertiesinstances. -
Method Summary
Modifier and TypeMethodDescriptionString[]toProperties(File aFile, ConfigLocator aConfigLocator) Loads or seeks the properties from the givenFile.toProperties(InputStream aInputStream) Reads the properties from the givenInputStream.toProperties(Class<?> aResourceClass, String aFilePath, ConfigLocator aConfigLocator) Loads the properties from the given file's path.toProperties(Object aObj) Create aImmutableResourcePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.toProperties(String aFilePath, ConfigLocator aConfigLocator) Loads the properties from the given file's path.toProperties(URL aUrl) Loads the properties from the givenURL.toProperties(Map<?, ?> aProperties) Create aImmutableResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations.toProperties(ImmutableProperties aProperties) Create aImmutableResourcePropertiesinstance containing the elements of the providedImmutablePropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations.toProperties(Properties aProperties) Create aImmutableResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface ImmutableResourcePropertiesFactory
hasFilenameSuffix, hasFilenameSuffixMethods inherited from interface ResourcePropertiesFactory
toProperties, toProperties, toProperties
-
Constructor Details
-
JavaPropertiesFactory
public JavaPropertiesFactory()Constructs anXmlCanonicalTableFactoryfor creatingXmlPropertiesinstances. -
JavaPropertiesFactory
Constructs anXmlCanonicalTableFactoryfor creatingXmlPropertiesinstances.- Parameters:
aDocumentOptions- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).
-
-
Method Details
-
getFilenameSuffixes
- Specified by:
getFilenameSuffixesin interfaceFilenameSuffixesAccessor
-
toProperties
public ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, ConfigLocator aConfigLocator) throws IOException, ParseException Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ImmutableResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
public ResourceProperties toProperties(File aFile, ConfigLocator aConfigLocator) throws IOException, ParseException Loads or seeks the properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ImmutableResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
Reads the properties from the givenInputStream.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.- Returns:
- The accordingly constructed
ImmutableResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
Create aImmutableResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ImmutableResourceProperties.
-
toProperties
Create aImmutableResourcePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aObj- The object from which the elements are to be added.- Returns:
- The accordingly constructed
ImmutableResourceProperties.
-
toProperties
Create aImmutableResourcePropertiesinstance containing the elements of the providedImmutablePropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ImmutableResourceProperties.
-
toProperties
Create aImmutableResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ImmutableResourceProperties.
-
toProperties
public ResourceProperties toProperties(String aFilePath, ConfigLocator aConfigLocator) throws IOException, ParseException Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ImmutableResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
Loads the properties from the givenURL.- Specified by:
toPropertiesin interfaceImmutableResourcePropertiesFactory- Specified by:
toPropertiesin interfaceResourcePropertiesFactory- Parameters:
aUrl- TheURLfrom which to read the properties.- Returns:
- The accordingly constructed
ImmutableResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-