Class MapImmutableProperties
java.lang.Object
org.refcodes.properties.MapImmutableProperties
- All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String, String>
- Direct Known Subclasses:
ArgsProperties
The Class MapImmutableProperties.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for collecting properties and creatingImmutablePropertiesinstances.Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
FieldsFields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface ImmutableProperties
DEFAULT_COMMENT -
Constructor Summary
ConstructorsConstructorDescriptionCreates an empty immutableImmutablePropertiesobject.MapImmutableProperties(Object aObj) Create aImmutablePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.MapImmutableProperties(Map<?, ?> aProperties) Create aImmutablePropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapImmutableProperties(Properties aProperties) Create aPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapImmutableProperties(Property... aProperties) Create aImmutablePropertiesinstance containing the providedPropertyinstances' key/value-pairs. -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Creates a newMapImmutableProperties.Builderfor constructingImmutablePropertiesinstances.booleancontainsKey(Object aKey) booleancharReturns the default path delimiter as ofDelimiter.PATH.getType()inthashCode()booleanisEmpty()keySet()retrieveFrom(String aFromPath) retrieveTo(String aToPath) intsize()toDataStructure(String aFromPath) values()Methods inherited from class Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutableProperties
containsValue, getAnnotator, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
Field Details
-
_properties
-
-
Constructor Details
-
MapImmutableProperties
public MapImmutableProperties()Creates an empty immutableImmutablePropertiesobject. -
MapImmutableProperties
Create aImmutablePropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
MapImmutableProperties
Create aImmutablePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.
-
MapImmutableProperties
Create aPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
MapImmutableProperties
Create aImmutablePropertiesinstance containing the providedPropertyinstances' key/value-pairs.- Parameters:
aProperties- the properties to be added.
-
-
Method Details
-
containsKey
- Specified by:
containsKeyin interfaceKeys<String,String>
-
equals
-
get
-
getDelimiter
public char getDelimiter()Returns the default path delimiter as ofDelimiter.PATH.- Specified by:
getDelimiterin interfaceDelimiterAccessor- Specified by:
getDelimiterin interfaceImmutableProperties
-
getType
- Specified by:
getTypein interfaceImmutableProperties- Specified by:
getTypein interfaceTypeAccessor<String>
-
hashCode
-
isEmpty
public boolean isEmpty()- Specified by:
isEmptyin interfaceEmptyAccessor
-
keySet
-
retrieveFrom
- Specified by:
retrieveFromin interfaceImmutableCanonicalTable- Specified by:
retrieveFromin interfaceImmutablePathTable<String>- Specified by:
retrieveFromin interfaceImmutableProperties
-
retrieveTo
- Specified by:
retrieveToin interfaceImmutableCanonicalTable- Specified by:
retrieveToin interfaceImmutablePathTable<String>- Specified by:
retrieveToin interfaceImmutableProperties
-
size
public int size()- Specified by:
sizein interfaceContainable
-
toDataStructure
- Specified by:
toDataStructurein interfaceImmutablePathTable<String>
-
values
-
builder
Creates a newMapImmutableProperties.Builderfor constructingImmutablePropertiesinstances.- Returns:
- A new builder instance
-