Class ProfilePropertiesProjection

java.lang.Object
org.refcodes.properties.ProfilePropertiesProjection
All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String,String>

public class ProfilePropertiesProjection extends Object implements ImmutableProperties
The ProfilePropertiesProjection applies the runtime-profiles as of ProfileProperties.getRuntimeProfiles() onto the encapsulated ImmutableProperties (ProfileProperties) and provides a view of them ImmutableProperties (ProfileProperties) from the runtime-profiles' point of view e.g. as when runtime-profiles have been applied to them ImmutableProperties (ProfileProperties). In other words, the runtime-profiles are resolved and the result is provided as view: Under the hood, the provided ImmutableProperties are decorated with a ProfilePropertiesDecorator which then is used to provide the profile projection via ProfileProperties.toRuntimeProfile().