-
- All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.struct.CanonicalMap,org.refcodes.struct.Containable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.struct.Dictionary<String,String>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,org.refcodes.struct.InterOperableMap<String>,org.refcodes.struct.Keys<String,String>,org.refcodes.struct.PathMap<String>,org.refcodes.mixin.TypeAccessor<String>
- All Known Subinterfaces:
ProfileProperties,ProfileProperties.MutableProfileProperties,ProfileProperties.ProfilePropertiesBuilder,Properties.MutableProperties,Properties.PropertiesBuilder,PropertiesPrecedence,PropertiesPrecedence.MutablePropertiesPrecedence,PropertiesPrecedence.PropertiesPrecedenceBuilder,ResourceProperties,ResourceProperties.MutableResoureProperties,ResourceProperties.ResourcePropertiesBuilder,ScheduledResourceProperties,ScheduledResourceProperties.ScheduledMuableResourceProperties,ScheduledResourceProperties.ScheduledResourcePropertiesBuilder,StrictProperties,StrictProperties.MutableStrictProperties,StrictProperties.StrictPropertiesBuilder
- All Known Implementing Classes:
AbstractPropertiesBuilderDecorator,AbstractPropertiesDecorator,AbstractResourceProperties,AbstractResourcePropertiesBuilder,AbstractResourcePropertiesBuilderDecorator,AbstractResourcePropertiesDecorator,ArgsProperties,EnvironmentProperties,JavaProperties,JavaPropertiesBuilder,JsonProperties,JsonPropertiesBuilder,NormalizedPropertiesDecorator,PolyglotProperties,PolyglotPropertiesBuilder,ProfilePropertiesDecorator,ProfilePropertiesProjection,PropertiesBuilderImpl,PropertiesImpl,PropertiesPrecedenceBuilderComposite,PropertiesPrecedenceComposite,ScheduledResourcePropertiesBuilderDecorator,ScheduledResourcePropertiesDecorator,StrictPropertiesDecorator,SystemProperties,TomlProperties,TomlPropertiesBuilder,XmlProperties,XmlPropertiesBuilder,YamlProperties,YamlPropertiesBuilder
public interface Properties extends org.refcodes.struct.CanonicalMapThePropertiesare a specialization of theDictionary. Properties represent a collection ofStringkey andStringvalue pairs as properties usually occur in pure text form, to be converted to the required data types. For this reason, thePropertiesinterface provides additional conversion methods.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceProperties.MutablePropertiesThe interfaceProperties.MutablePropertiesdefines "dirty" methods allowing to modify ("mutate") the properties.static interfaceProperties.PropertiesBuilderThe interfaceProperties.PropertiesBuilderdefines builder functionality on top of the properties .-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder, org.refcodes.struct.CanonicalMap.MutableCanonicalMap
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
org.refcodes.struct.Dictionary.MutableDictionary<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<T extends Object>, org.refcodes.struct.InterOperableMap.MutableInterOperableMap<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K extends Object,V extends Object>, org.refcodes.struct.Keys.MutableValues<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
org.refcodes.struct.PathMap.MutablePathMap<T extends Object>, org.refcodes.struct.PathMap.PathMapBuilder<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Field Summary
Fields Modifier and Type Field Description static StringDEFAULT_COMMENT
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default booleancontainsValue(Object value)default chargetAnnotator()Returns the default path annotator as ofAnnotator.JAVA.default chargetDelimiter()Returns the default path delimiter as ofDelimiter.PATH.default PropertiesgetDir(Object aPath)default PropertiesgetDir(Object... aPathElements)default PropertiesgetDir(String aPath)default PropertiesgetDir(String... aPathElements)default PropertiesgetDir(Collection<?> aPathElements)default PropertiesgetDirAt(int aIndex)default PropertiesgetDirAt(Object[] aPathElements, int aIndex)default PropertiesgetDirAt(Object aPath, int aIndex)default PropertiesgetDirAt(String[] aPathElements, int aIndex)default PropertiesgetDirAt(String aPath, int aIndex)default PropertiesgetDirAt(Collection<?> aPathElements, int aIndex)default Properties[]getDirs(Object aPath)default Properties[]getDirs(Object... aPathElements)default Properties[]getDirs(String aPath)default Properties[]getDirs(String... aPathElements)default Properties[]getDirs(Collection<?> aPathElements)default Class<String>getType()default Propertiesquery(Object... aQueryElements)default Propertiesquery(String aPathQuery)default Propertiesquery(String... aQueryElements)default Propertiesquery(Collection<?> aQueryElements)default Propertiesquery(Pattern aRegExp)default PropertiesqueryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath)default PropertiesqueryBetween(Object aFromPath, Object aPathQuery, Object aToPath)default PropertiesqueryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath)default PropertiesqueryBetween(String aPathQuery, String aFromPath, String aToPath)default PropertiesqueryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath)default PropertiesqueryFrom(Object[] aPathQuery, Object[] aFromPath)default PropertiesqueryFrom(Object aPathQuery, Object aFromPath)default PropertiesqueryFrom(String[] aPathQuery, String[] aFromPath)default PropertiesqueryFrom(String aPathQuery, String aFromPath)default PropertiesqueryFrom(Collection<?> aPathQuery, Collection<?> aFromPath)default PropertiesqueryFrom(Pattern aRegExp, String aFromPath)default PropertiesqueryTo(Object[] aPathQuery, String aToPath)default PropertiesqueryTo(Object aPathQuery, String aToPath)default PropertiesqueryTo(String[] aPathQuery, String aToPath)default PropertiesqueryTo(String aPathQuery, String aToPath)default PropertiesqueryTo(Collection<?> aPathQuery, String aToPath)default PropertiesqueryTo(Pattern aRegExp, String aToPath)default PropertiesretrieveBetween(Object[] aFromPath, Object[] aToPath)default PropertiesretrieveBetween(Object aFromPath, Object aToPath)default PropertiesretrieveBetween(String[] aFromPath, String[] aToPath)default PropertiesretrieveBetween(String aFromPath, String aToPath)default PropertiesretrieveBetween(Collection<?> aFromPath, Collection<?> aToPath)default PropertiesretrieveFrom(Object aParentPath)default PropertiesretrieveFrom(Object... aPathElements)PropertiesretrieveFrom(String aFromPath)default PropertiesretrieveFrom(String... aPathElements)default PropertiesretrieveFrom(Collection<?> aPathElements)default PropertiesretrieveTo(Object aToPath)default PropertiesretrieveTo(Object... aToPathElements)PropertiesretrieveTo(String aToPath)default PropertiesretrieveTo(String... aToPathElements)default PropertiesretrieveTo(Collection<?> aToPathElements)-
Methods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toProperties
-
Methods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOr
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, values
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
-
-
-
Field Detail
-
DEFAULT_COMMENT
static final String DEFAULT_COMMENT
-
-
Method Detail
-
containsValue
default boolean containsValue(Object value)
-
getDelimiter
default char getDelimiter()
Returns the default path delimiter as ofDelimiter.PATH.- Specified by:
getDelimiterin interfaceorg.refcodes.mixin.DelimiterAccessor
-
getAnnotator
default char getAnnotator()
Returns the default path annotator as ofAnnotator.JAVA.- Specified by:
getAnnotatorin interfaceorg.refcodes.mixin.AnnotatorAccessor
-
getDirAt
default Properties getDirAt(int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getDirAt
default Properties getDirAt(String aPath, int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getDirAt
default Properties getDirAt(Collection<?> aPathElements, int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getDirAt
default Properties getDirAt(Object aPath, int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getDirAt
default Properties getDirAt(Object[] aPathElements, int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getDirAt
default Properties getDirAt(String[] aPathElements, int aIndex)
- Specified by:
getDirAtin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirAtin interfaceorg.refcodes.struct.PathMap<String>
-
getType
default Class<String> getType()
- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<String>
-
query
default Properties query(Collection<?> aQueryElements)
- Specified by:
queryin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryin interfaceorg.refcodes.struct.PathMap<String>
-
query
default Properties query(Object... aQueryElements)
- Specified by:
queryin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryin interfaceorg.refcodes.struct.PathMap<String>
-
query
default Properties query(String aPathQuery)
- Specified by:
queryin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryin interfaceorg.refcodes.struct.PathMap<String>
-
query
default Properties query(Pattern aRegExp)
- Specified by:
queryin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryin interfaceorg.refcodes.struct.PathMap<String>
-
query
default Properties query(String... aQueryElements)
- Specified by:
queryin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryin interfaceorg.refcodes.struct.PathMap<String>
-
queryBetween
default Properties queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath)
- Specified by:
queryBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
queryBetween
default Properties queryBetween(Object aFromPath, Object aPathQuery, Object aToPath)
- Specified by:
queryBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
queryBetween
default Properties queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath)
- Specified by:
queryBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
queryBetween
default Properties queryBetween(String aPathQuery, String aFromPath, String aToPath)
- Specified by:
queryBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
queryBetween
default Properties queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath)
- Specified by:
queryBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(Object aPathQuery, Object aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(Object[] aPathQuery, Object[] aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(String aPathQuery, String aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(Pattern aRegExp, String aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryFrom
default Properties queryFrom(String[] aPathQuery, String[] aFromPath)
- Specified by:
queryFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryFromin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(Collection<?> aPathQuery, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(Object aPathQuery, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(Object[] aPathQuery, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(String aPathQuery, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(Pattern aRegExp, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
queryTo
default Properties queryTo(String[] aPathQuery, String aToPath)
- Specified by:
queryToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
queryToin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveBetween
default Properties retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath)
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveBetween
default Properties retrieveBetween(Object aFromPath, Object aToPath)
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveBetween
default Properties retrieveBetween(Object[] aFromPath, Object[] aToPath)
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveBetween
default Properties retrieveBetween(String aFromPath, String aToPath)
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveBetween
default Properties retrieveBetween(String[] aFromPath, String[] aToPath)
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveFrom
default Properties retrieveFrom(Collection<?> aPathElements)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveFrom
default Properties retrieveFrom(Object aParentPath)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveFrom
default Properties retrieveFrom(Object... aPathElements)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveFrom
Properties retrieveFrom(String aFromPath)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveFrom
default Properties retrieveFrom(String... aPathElements)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>
-
getDir
default Properties getDir(Collection<?> aPathElements)
- Specified by:
getDirin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirin interfaceorg.refcodes.struct.PathMap<String>
-
getDir
default Properties getDir(Object aPath)
- Specified by:
getDirin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirin interfaceorg.refcodes.struct.PathMap<String>
-
getDir
default Properties getDir(Object... aPathElements)
- Specified by:
getDirin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirin interfaceorg.refcodes.struct.PathMap<String>
-
getDir
default Properties getDir(String aPath)
- Specified by:
getDirin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirin interfaceorg.refcodes.struct.PathMap<String>
-
getDir
default Properties getDir(String... aPathElements)
- Specified by:
getDirin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirin interfaceorg.refcodes.struct.PathMap<String>
-
getDirs
default Properties[] getDirs(Collection<?> aPathElements)
- Specified by:
getDirsin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirsin interfaceorg.refcodes.struct.PathMap<String>
-
getDirs
default Properties[] getDirs(Object aPath)
- Specified by:
getDirsin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirsin interfaceorg.refcodes.struct.PathMap<String>
-
getDirs
default Properties[] getDirs(Object... aPathElements)
- Specified by:
getDirsin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirsin interfaceorg.refcodes.struct.PathMap<String>
-
getDirs
default Properties[] getDirs(String aPath)
- Specified by:
getDirsin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirsin interfaceorg.refcodes.struct.PathMap<String>
-
getDirs
default Properties[] getDirs(String... aPathElements)
- Specified by:
getDirsin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
getDirsin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveTo
default Properties retrieveTo(Collection<?> aToPathElements)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveTo
default Properties retrieveTo(Object aToPath)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveTo
default Properties retrieveTo(Object... aToPathElements)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveTo
Properties retrieveTo(String aToPath)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>
-
retrieveTo
default Properties retrieveTo(String... aToPathElements)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>
-
-