Module org.refcodes.properties
Package org.refcodes.properties
Interface Properties.MutableProperties
-
- All Superinterfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.struct.CanonicalMap,org.refcodes.struct.CanonicalMap.MutableCanonicalMap,org.refcodes.mixin.Clearable,org.refcodes.struct.Containable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.struct.Dictionary<String,String>,org.refcodes.struct.Dictionary.MutableDictionary<String,String>,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,org.refcodes.struct.InterOperableMap<String>,org.refcodes.struct.InterOperableMap.MutableInterOperableMap<String>,org.refcodes.struct.Keys<String,String>,org.refcodes.struct.Keys.MutableKeys<String,String>,org.refcodes.struct.Keys.MutableValues<String,String>,Map<String,String>,org.refcodes.struct.PathMap<String>,org.refcodes.struct.PathMap.MutablePathMap<String>,Properties,org.refcodes.mixin.TypeAccessor<String>
- All Known Subinterfaces:
ProfileProperties.MutableProfileProperties,ProfileProperties.ProfilePropertiesBuilder,Properties.PropertiesBuilder,ResourceProperties.MutableResoureProperties,ResourceProperties.ResourcePropertiesBuilder,ScheduledResourceProperties.ScheduledMuableResourceProperties,ScheduledResourceProperties.ScheduledResourcePropertiesBuilder,StrictProperties.MutableStrictProperties,StrictProperties.StrictPropertiesBuilder
- All Known Implementing Classes:
AbstractPropertiesBuilderDecorator,AbstractResourcePropertiesBuilder,AbstractResourcePropertiesBuilderDecorator,JavaPropertiesBuilder,JsonPropertiesBuilder,PolyglotPropertiesBuilder,PropertiesBuilderImpl,ScheduledResourcePropertiesBuilderDecorator,TomlPropertiesBuilder,XmlPropertiesBuilder,YamlPropertiesBuilder
- Enclosing interface:
- Properties
public static interface Properties.MutableProperties extends Properties, org.refcodes.struct.CanonicalMap.MutableCanonicalMap
The interfaceProperties.MutablePropertiesdefines "dirty" methods allowing to modify ("mutate") the properties.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder, org.refcodes.struct.CanonicalMap.MutableCanonicalMap
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
org.refcodes.struct.Dictionary.MutableDictionary<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<K extends Object,V extends Object,B extends org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<K,V,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<T extends Object>, org.refcodes.struct.InterOperableMap.MutableInterOperableMap<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K extends Object,V extends Object>, org.refcodes.struct.Keys.MutableValues<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface java.util.Map
Map.Entry<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
org.refcodes.struct.PathMap.MutablePathMap<T extends Object>, org.refcodes.struct.PathMap.PathMapBuilder<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.properties.Properties
Properties.MutableProperties, Properties.PropertiesBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Field Summary
-
Fields inherited from interface org.refcodes.properties.Properties
DEFAULT_COMMENT
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default booleancontainsValue(Object value)default Stringdelete(org.refcodes.struct.Property aProperty)Removes a property identified by the key of the providedProperty(the value of thePropertyis ignored).default voidinsert(Properties aFrom)Method to semantically emphasize that we support our own types.default voidinsertBetween(String aToPath, Properties aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertFrom(Properties aFrom, String aFromPath)Method to semantically emphasize that we support our own types.default voidinsertTo(String aToPath, Properties aFrom)Method to semantically emphasize that we support our own types.default Stringput(org.refcodes.struct.Relation<String,String> aRelation)default voidputAll(Map<? extends String,? extends String> aProperties)default voidputAll(Properties aProperties)This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.default voidputAll(Properties aProperties)This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.default PropertiesputDirAt(int aIndex, Object aDir)default PropertiesputDirAt(int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesputDirAt(Object[] aPathElements, int aIndex, Object aDir)default PropertiesputDirAt(Object[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesputDirAt(Object aPath, int aIndex, Object aDir)default PropertiesputDirAt(Object aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesputDirAt(String[] aPathElements, int aIndex, Object aDir)default PropertiesputDirAt(String[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesputDirAt(String aPath, int aIndex, Object aDir)default PropertiesputDirAt(String aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesputDirAt(Collection<?> aPathElements, int aIndex, Object aDir)default PropertiesputDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir)default PropertiesremoveAll(Object aPathQuery)default PropertiesremoveAll(Object... aPathQueryElemments)default PropertiesremoveAll(String aPathQuery)default PropertiesremoveAll(String... aPathQueryElemments)default PropertiesremoveAll(Collection<?> aPathQueryElemments)default PropertiesremoveAll(Pattern aRegExp)default PropertiesremoveDirAt(int aIndex)default PropertiesremoveDirAt(Object[] aPathElements, int aIndex)default PropertiesremoveDirAt(Object aPath, int aIndex)default PropertiesremoveDirAt(String[] aPathElements, int aIndex)default PropertiesremoveDirAt(String aPath, int aIndex)default PropertiesremoveFrom(Object aPath)default PropertiesremoveFrom(Object... aPathElements)default PropertiesremoveFrom(String aPath)default PropertiesremoveFrom(String... aPathElements)default PropertiesremovePaths(String... aPaths)default PropertiesremovePaths(Collection<?> aPaths)-
Methods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toProperties
-
Methods inherited from interface org.refcodes.struct.CanonicalMap.MutableCanonicalMap
insert, insertBetween, insertFrom, insertTo, put, put, put, put, putAll, removeFrom, toDump
-
Methods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOr
-
Methods inherited from interface org.refcodes.struct.InterOperableMap.MutableInterOperableMap
insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putString
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, values
-
Methods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
Methods inherited from interface org.refcodes.struct.PathMap.MutablePathMap
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCode
-
Methods inherited from interface org.refcodes.properties.Properties
getAnnotator, getDelimiter, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
-
-
-
Method Detail
-
containsValue
default boolean containsValue(Object value)
- Specified by:
containsValuein interfaceorg.refcodes.struct.CanonicalMap- Specified by:
containsValuein interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
containsValuein interfaceorg.refcodes.struct.InterOperableMap.MutableInterOperableMap<String>- Specified by:
containsValuein interfaceorg.refcodes.struct.Keys<String,String>- Specified by:
containsValuein interfaceMap<String,String>- Specified by:
containsValuein interfaceProperties
-
delete
default String delete(org.refcodes.struct.Property aProperty)
Removes a property identified by the key of the providedProperty(the value of thePropertyis ignored).- Parameters:
aProperty- ThePropertywhich's key is to be removed.- Returns:
- The removed value of the key or null if there was not such a key.
-
insert
default void insert(Properties aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insert(Object).- Parameters:
aFrom- ThePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.
-
insertBetween
default void insertBetween(String aToPath, Properties aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertBetween(String, Object, String).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- ThePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertFrom
default void insertFrom(Properties aFrom, String aFromPath)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertFrom(Object, String).- Parameters:
aFrom- ThePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.aFromPath- The path from where to start adding elements of the provided object.
-
insertTo
default void insertTo(String aToPath, Properties aFrom)
Method to semantically emphasize that we support our own types. Actually delegates toPathMap.MutablePathMap.insertTo(String, Object).- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aFrom- ThePropertieswhich is to be inspected with the therein contained values being added with their according determined paths.
-
putAll
default void putAll(Properties aProperties)
This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.- Specified by:
putAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Parameters:
aProperties- APropertiescontaining the key/value-pairs to be inserted.
-
putAll
default void putAll(Properties aProperties)
This method inserts all elements (key/value-pairs) found in the providedPropertiesinstances of interoperability reasons.- Parameters:
aProperties- APropertiescontaining the key/value pairs to be inserted.
-
putDirAt
default Properties putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(Object aPath, int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(Object aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(Object[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(Object[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(String aPath, int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(String aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(String[] aPathElements, int aIndex, Object aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
putDirAt
default Properties putDirAt(String[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) throws IllegalArgumentException
- Specified by:
putDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
putDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>- Throws:
IllegalArgumentException
-
removePaths
default Properties removePaths(Collection<?> aPaths)
- Specified by:
removePathsin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removePathsin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removePaths
default Properties removePaths(String... aPaths)
- Specified by:
removePathsin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removePathsin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(String... aPathQueryElemments)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(Object... aPathQueryElemments)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(Collection<?> aPathQueryElemments)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(String aPathQuery)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(Pattern aRegExp)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeAll
default Properties removeAll(Object aPathQuery)
- Specified by:
removeAllin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeAllin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeDirAt
default Properties removeDirAt(int aIndex)
- Specified by:
removeDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeDirAt
default Properties removeDirAt(Object aPath, int aIndex)
- Specified by:
removeDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeDirAt
default Properties removeDirAt(Object[] aPathElements, int aIndex)
- Specified by:
removeDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeDirAt
default Properties removeDirAt(String aPath, int aIndex)
- Specified by:
removeDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeDirAt
default Properties removeDirAt(String[] aPathElements, int aIndex)
- Specified by:
removeDirAtin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeDirAtin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeFrom
default Properties removeFrom(Object... aPathElements)
- Specified by:
removeFromin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeFromin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeFrom
default Properties removeFrom(Object aPath)
- Specified by:
removeFromin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeFromin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeFrom
default Properties removeFrom(String aPath)
- Specified by:
removeFromin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeFromin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
removeFrom
default Properties removeFrom(String... aPathElements)
- Specified by:
removeFromin interfaceorg.refcodes.struct.CanonicalMap.MutableCanonicalMap- Specified by:
removeFromin interfaceorg.refcodes.struct.PathMap.MutablePathMap<String>
-
-