Enum PropertiesPath

    • Enum Constant Detail

      • RUNTIME_PROFILES_PATH

        public static final PropertiesPath RUNTIME_PROFILES_PATH
        Default path where the profile(s) are to be retrieved by the ProfileProperties and the like implementations.
    • Method Detail

      • values

        public static PropertiesPath[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (PropertiesPath c : PropertiesPath.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static PropertiesPath valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • getPath

        public String getPath()
        Specified by:
        getPath in interface org.refcodes.mixin.PathAccessor