Module org.refcodes.properties
Package org.refcodes.properties
Interface ResourceLoaderMixin<B extends ResourceLoaderMixin<B>>
-
public interface ResourceLoaderMixin<B extends ResourceLoaderMixin<B>>This interface provides builder additions (as of the builder pattern for chained configuring method calls) for "dynamic"ResourceProperties: AsResourcePropertiesare immutable from an interface's point of view, there are no mutating methods provided. Sub-types of theResourcePropertiesmight need to load the properties after instantiation. Such types might implement this interface, providing means to load from resources after instantiation.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default BwithFile(File aFile)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFile(File aFile, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFile(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().BwithFile(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFilePath(Class<?> aResourceClass, String aFilePath)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFilePath(Class<?> aResourceClass, String aFilePath, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().BwithFilePath(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFilePath(String aFilePath)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFilePath(String aFilePath, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithFilePath(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().default BwithInputStream(InputStream aInputStream)Reads the properties from the givenInputStream.BwithInputStream(InputStream aInputStream, char... aDelimiters)Reads the properties from the givenInputStream.default BwithUrl(URL aUrl)Loads the properties from the givenURL.BwithUrl(URL aUrl, char... aDelimiters)Loads the properties from the givenURL.
-
-
-
Method Detail
-
withFile
default B withFile(File aFile) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFile- The file of the properties to load.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFile
default B withFile(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFile- The file of the properties to load.aConfigLocator- TheConfigLocatorspecifying where to seek for properties.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFile
default B withFile(File aFile, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFile- The file of the properties to load.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFile
B withFile(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFile- The file of the properties to load.aConfigLocator- TheConfigLocatorspecifying where to seek for properties.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withInputStream
default B withInputStream(InputStream aInputStream) throws IOException, ParseException
Reads the properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withInputStream
B withInputStream(InputStream aInputStream, char... aDelimiters) throws IOException, ParseException
Reads the properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
default B withFilePath(String aFilePath) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFilePath- The file of the properties file to load.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
default B withFilePath(String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFilePath- The file of the properties file to load.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
default B withFilePath(Class<?> aResourceClass, String aFilePath) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file of the properties file to load.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
default B withFilePath(Class<?> aResourceClass, String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file of the properties file to load.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
default B withFilePath(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aFilePath- The file of the properties file to load.aConfigLocator- TheConfigLocatorspecifying where to seek for properties.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withFilePath
B withFilePath(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads a properties file from the file directly or (if not found) from first folder containing such a file as of the specification for the methodConfigLocator.getFolders().- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file of the properties file to load.aConfigLocator- TheConfigLocatorspecifying where to seek for properties.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withUrl
default B withUrl(URL aUrl) throws IOException, ParseException
Loads the properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
withUrl
B withUrl(URL aUrl, char... aDelimiters) throws IOException, ParseException
Loads the properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.aDelimiters- The delimiters in the properties file to identity a path delimiter.- Returns:
- This instance as of the builder pattern for chained method calls.
- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
-