-
- All Superinterfaces:
org.refcodes.mixin.FilenameSuffixesAccessor
- All Known Subinterfaces:
ResourcePropertiesFactory.ResourcePropertiesBuilderFactory
- All Known Implementing Classes:
JavaProperties.JavaPropertiesFactory,JavaPropertiesBuilder.JavaPropertiesBuilderFactory,JsonProperties.JsonPropertiesFactory,JsonPropertiesBuilder.JsonPropertiesBuilderFactory,PolyglotProperties.PolyglotPropertiesFactory,PolyglotPropertiesBuilder.PolyglotPropertiesBuilderFactory,TomlProperties.TomlPropertiesFactory,TomlPropertiesBuilder.TomlPropertiesBuilderFactory,XmlProperties.XmlPropertiesFactory,XmlPropertiesBuilder.XmlPropertiesBuilderFactory,YamlProperties.YamlPropertiesFactory,YamlPropertiesBuilder.YamlPropertiesBuilderFactory
public interface ResourcePropertiesFactory extends org.refcodes.mixin.FilenameSuffixesAccessorFactory interface for creatingResourcePropertiesinstances.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceResourcePropertiesFactory.ResourcePropertiesBuilderFactoryFactory interface for creatingResourceProperties.ResourcePropertiesBuilderinstances.-
Nested classes/interfaces inherited from interface org.refcodes.mixin.FilenameSuffixesAccessor
org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesBuilder<B extends org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesBuilder<B>>, org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesMutator, org.refcodes.mixin.FilenameSuffixesAccessor.FilenameSuffixesProperty
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default ResourcePropertiestoProperties(File aFile)Loads the properties from the givenFile.default ResourcePropertiestoProperties(File aFile, char... aDelimiters)Loads the properties from the givenFile.default ResourcePropertiestoProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads or seeks the properties from the givenFile.ResourcePropertiestoProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads or seeks the properties from the givenFile.default ResourcePropertiestoProperties(InputStream aInputStream)Reads the properties from the givenInputStream.ResourcePropertiestoProperties(InputStream aInputStream, char... aDelimiters)Reads the properties from the givenInputStream.default ResourcePropertiestoProperties(Class<?> aResourceClass, String aFilePath)Loads the properties from the given file's path.default ResourcePropertiestoProperties(Class<?> aResourceClass, String aFilePath, char... aDelimiters)Loads the properties from the given file's path.default ResourcePropertiestoProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads the properties from the given file's path.ResourcePropertiestoProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the properties from the given file's path.ResourcePropertiestoProperties(Object aObj)Create aResourcePropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.default ResourcePropertiestoProperties(String aFilePath)Loads the properties from the given file's path.default ResourcePropertiestoProperties(String aFilePath, char... aDelimiters)Loads the properties from the given file's path.default ResourcePropertiestoProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads the properties from the given file's path.ResourcePropertiestoProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the properties from the given file's path.default ResourcePropertiestoProperties(URL aUrl)Loads the properties from the givenURL.ResourcePropertiestoProperties(URL aUrl, char... aDelimiters)Loads the properties from the givenURL.ResourcePropertiestoProperties(Map<?,?> aProperties)Create aResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarationsResourcePropertiestoProperties(Properties aProperties)Create aResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarationsResourcePropertiestoProperties(Properties.PropertiesBuilder aProperties)Create aResourcePropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations
-
-
-
Method Detail
-
toProperties
ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
ResourceProperties toProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads or seeks the properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
ResourceProperties toProperties(InputStream aInputStream, char... aDelimiters) throws IOException, ParseException
Reads the properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
ResourceProperties toProperties(Map<?,?> aProperties)
Create aResourcePropertiesinstance containing the elements of the providedMapinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
ResourceProperties toProperties(Object aObj)
Create aResourcePropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
ResourceProperties toProperties(Properties aProperties)
Create aResourcePropertiesinstance containing the elements of the providedPropertiesinstance using the path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
ResourceProperties toProperties(Properties.PropertiesBuilder aProperties)
Create aResourcePropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.- Returns:
- The accordingly constructed
ResourceProperties.
-
toProperties
ResourceProperties toProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
ResourceProperties toProperties(URL aUrl, char... aDelimiters) throws IOException, ParseException
Loads the properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath) throws IOException, ParseException
Loads the properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(File aFile) throws IOException, ParseException
Loads the properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(File aFile, char... aDelimiters) throws IOException, ParseException
Loads the properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads or seeks the properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(InputStream aInputStream) throws IOException, ParseException
Reads the properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(String aFilePath) throws IOException, ParseException
Loads the properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads the properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads the properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
toProperties
default ResourceProperties toProperties(URL aUrl) throws IOException, ParseException
Loads the properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.- Returns:
- The accordingly constructed
ResourceProperties. - Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
-