Class SystemProperties

java.lang.Object
org.refcodes.properties.SystemProperties
All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String,String>

public class SystemProperties extends Object implements ImmutableProperties
Extension of the ImmutableProperties type overwriting methods in order to access system properties as passed via the "-Dkey=value" when launching the JVM (e.g.java -Dconsole.width=220) The keys are transformed to a system properties by removing a prefixed "/" path delimiter (as of ImmutableProperties.getDelimiter() and converting all other path delimiters "/" to the system property's (de facto standard) separator ".". If accessing failed, then the lower case version of the so transformed key is probed. Accessing a system property "console.width" would be done with the path "/console/width".