Uses of Interface
org.refcodes.properties.ImmutableProperties.MutableProperties
-
Uses of ImmutableProperties.MutableProperties in org.refcodes.properties
Subinterfaces of ImmutableProperties.MutableProperties in org.refcodes.propertiesModifier and TypeInterfaceDescriptionstatic interfaceThe interfaceImmutableResourceProperties.MutableResourePropertiesdefines "dirty" methods allowing to modify ("mutate") theImmutableResourceProperties.static interfaceThe interfaceImmutableScheduledResourceProperties.ScheduledMuableResourcePropertiesdefines "dirty" methods allowing to modify ("mutate") theImmutableScheduledResourceProperties.static interfaceThe Interface MutableStrictProperties.interfaceThe interfacePropertiesdefines builder functionality on top of the properties .interfaceThe interfaceResourcePropertiesdefines builder functionality on top of theImmutableResourceProperties.MutableResoureProperties.interfaceThe interfaceScheduledResourcePropertiesdefines builder functionality on top of theImmutableScheduledResourceProperties.ScheduledMuableResourceProperties.interfaceTheStrictPropertiestype extends theImmutableStrictProperties.MutableStrictPropertiestype with all the getters to throw aKeyNotFoundRuntimeExceptioninstead of returning null in case the key was not found.Classes in org.refcodes.properties that implement ImmutableProperties.MutablePropertiesModifier and TypeClassDescriptionclassAbstractPropertiesDecorator<T extends Properties>The Class AbstractPropertiesDecorator.classImplementation of the mutableResourcePropertiesinterface.classThe Class AbstractResourcePropertiesDecorator.classImplementation of theResourcePropertiesinterface with support of so called "Java properties" (or just "properties").classImplementation of theResourcePropertiesinterface with support of so called "JSON properties" (or just "properties").static classBuilder for collecting properties and creatingImmutablePropertiesinstances.classclassImplementation of theResourcePropertiesinterface with support of so called "PolyglotProperties" (or just "properties").classTheScheduledResourcePropertiesDecoratordecoratesResourcePropertiesfrom which the properties are to be reloaded periodically viaAbstractResourcePropertiesDecorator.reload(ReloadMode).classTheStrictPropertiesDecoratortype decorates aImmutablePropertiesinstance with all the getters to throw aKeyNotFoundRuntimeExceptioninstead of returning null in case the key was not found.classImplementation of theResourcePropertiesinterface with support of so called "TOML properties".classImplementation of theResourcePropertiesinterface with support of so called "XML properties" (or just "properties").classImplementation of theResourcePropertiesinterface with support of so called "YAML properties" (or just "properties").