Uses of Enum Class
org.refcodes.properties.PropertiesPath
-
Uses of PropertiesPath in org.refcodes.properties
Subclasses with type arguments of type PropertiesPath in org.refcodes.propertiesModifier and TypeClassDescriptionenumEnumeration representing defined path values.Methods in org.refcodes.properties that return PropertiesPathModifier and TypeMethodDescriptionstatic PropertiesPathReturns the enum constant of this class with the specified name.static PropertiesPath[]PropertiesPath.values()Returns an array containing the constants of this enum class, in the order they are declared.