Uses of Enum Class
org.refcodes.properties.ReloadMode
-
Uses of ReloadMode in org.refcodes.properties
Subclasses with type arguments of type ReloadMode in org.refcodes.propertiesModifier and TypeClassDescriptionenumMode of operation regarding theImmutableResourceProperties.reload(ReloadMode)method.Methods in org.refcodes.properties that return ReloadModeModifier and TypeMethodDescriptionstatic ReloadModeReturns the enum constant of this class with the specified name.static ReloadMode[]ReloadMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.properties with parameters of type ReloadModeModifier and TypeMethodDescriptionAbstractImmutableResourcePropertiesDecorator.reload(ReloadMode aReloadMode) Reloads theImmutableResourcePropertiesfrom the resource to which theImmutableResourcePropertiesare attached to (such as aFileas ofImmutableResourceProperties.MutableResoureProperties.loadFrom(File)orImmutableResourceProperties.MutableResoureProperties.saveTo(File)).AbstractResourceProperties.reload(ReloadMode aReloadMode) Reloads theImmutableResourcePropertiesfrom the resource to which theImmutableResourcePropertiesare attached to (such as aFileas ofImmutableResourceProperties.MutableResoureProperties.loadFrom(File)orImmutableResourceProperties.MutableResoureProperties.saveTo(File)).AbstractResourcePropertiesDecorator.reload(ReloadMode aReloadMode) Reloads theImmutableResourcePropertiesfrom the resource to which theImmutableResourcePropertiesare attached to (such as aFileas ofImmutableResourceProperties.MutableResoureProperties.loadFrom(File)orImmutableResourceProperties.MutableResoureProperties.saveTo(File)).ImmutableResourceProperties.reload(ReloadMode aReloadMode) Reloads theImmutableResourcePropertiesfrom the resource to which theImmutableResourcePropertiesare attached to (such as aFileas ofImmutableResourceProperties.MutableResoureProperties.loadFrom(File)orImmutableResourceProperties.MutableResoureProperties.saveTo(File)).PolyglotProperties.reload(ReloadMode aReloadMode) Reloads theImmutableResourcePropertiesfrom the resource to which theImmutableResourcePropertiesare attached to (such as aFileas ofImmutableResourceProperties.MutableResoureProperties.loadFrom(File)orImmutableResourceProperties.MutableResoureProperties.saveTo(File)).PropertiesSugar.schedule(ImmutableResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode) Creates aImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).PropertiesSugar.schedule(ImmutableResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode, ThreadMode aThreadMode) Creates aImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).PropertiesSugar.schedule(ImmutableResourceProperties aProperties, ReloadMode aReloadMode) Creates aImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).PropertiesSugar.schedule(ImmutableResourceProperties aProperties, ReloadMode aReloadMode, ThreadMode aThreadMode) Creates aImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).static ScheduledResourcePropertiesPropertiesSugar.schedule(ResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode) Creates aScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).static ScheduledResourcePropertiesPropertiesSugar.schedule(ResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode, ThreadMode aThreadMode) Creates aScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).static ScheduledResourcePropertiesPropertiesSugar.schedule(ResourceProperties aProperties, ReloadMode aReloadMode) Creates aScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORM) and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).static ScheduledResourcePropertiesPropertiesSugar.schedule(ResourceProperties aProperties, ReloadMode aReloadMode, ThreadMode aThreadMode) Creates aScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORM) and the given orphan removal strategy (as ofImmutableResourceProperties.reload(ReloadMode)being called with your argument).Constructors in org.refcodes.properties with parameters of type ReloadModeModifierConstructorDescriptionImmutableScheduledResourcePropertiesDecorator(ImmutableResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode) Constructs theImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofAbstractImmutableResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ImmutableScheduledResourcePropertiesDecorator(ImmutableResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode, ThreadMode aThreadMode) Constructs theImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofAbstractImmutableResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ImmutableScheduledResourcePropertiesDecorator(ImmutableResourceProperties aProperties, ReloadMode aReloadMode) Constructs theImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofAbstractImmutableResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ImmutableScheduledResourcePropertiesDecorator(ImmutableResourceProperties aProperties, ReloadMode aReloadMode, ThreadMode aThreadMode) Constructs theImmutableScheduledResourcePropertiesDecoratorwrapping the givenImmutableResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofAbstractImmutableResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ScheduledResourcePropertiesDecorator(ResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode) Constructs theScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofAbstractResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ScheduledResourcePropertiesDecorator(ResourceProperties aProperties, int aScheduleTimeMillis, ReloadMode aReloadMode, ThreadMode aThreadMode) Constructs theScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the given poll loop time and the given orphan removal strategy (as ofAbstractResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ScheduledResourcePropertiesDecorator(ResourceProperties aProperties, ReloadMode aReloadMode) Constructs theScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofAbstractResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).ScheduledResourcePropertiesDecorator(ResourceProperties aProperties, ReloadMode aReloadMode, ThreadMode aThreadMode) Constructs theScheduledResourcePropertiesDecoratorwrapping the givenResourcePropertieswith setting the the default poll loop time of 10 seconds (as ofIoPollLoopTime.NORMand the given orphan removal strategy (as ofAbstractResourcePropertiesDecorator.reload(ReloadMode)being called with your argument).