Serialized Form
-
Package org.refcodes.properties
-
Class org.refcodes.properties.AbstractResourcePropertiesBuilder extends PropertiesBuilderImpl implements Serializable
- serialVersionUID:
- 1L
-
Serialized Fields
-
_factory
org.refcodes.struct.ext.factory.CanonicalMapFactory _factory
TheCanonicalMapFactorycannot be instantiated as a member variable as a super-class's constructor uses a method defined in this sub-class which uses this factory. This will result in an uninitialized factory when the super-constructor invokes the according method. Therefore with the methodAbstractResourcePropertiesBuilder.getCanonicalMapFactory()we use lazy instantiation to overcome this challenge. -
_propertiesFile
File _propertiesFile
-
-
Class org.refcodes.properties.ConfigurationRuntimeException extends org.refcodes.exception.AbstractRuntimeException implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.JavaPropertiesBuilder extends AbstractResourcePropertiesBuilder implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.JsonPropertiesBuilder extends AbstractResourcePropertiesBuilder implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.PropertiesBuilderImpl extends org.refcodes.struct.CanonicalMapBuilderImpl implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.TomlPropertiesBuilder extends AbstractResourcePropertiesBuilder implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.XmlPropertiesBuilder extends AbstractResourcePropertiesBuilder implements Serializable
- serialVersionUID:
- 1L
-
Class org.refcodes.properties.YamlPropertiesBuilder extends AbstractResourcePropertiesBuilder implements Serializable
- serialVersionUID:
- 1L
-