All Classes and Interfaces
Class
Description
Decorates the provided
ImmutableProperties and delegates method calls
to them ImmutableProperties.Decorates the provided
ImmutableResourceProperties and delegates
method calls to them ImmutableResourceProperties.The Class AbstractPropertiesDecorator.
Implementation of the mutable
ResourceProperties interface.The Class AbstractResourcePropertiesDecorator.
The
ArgsProperties takes them command line arguments "as is" and
converts them into key/value pairs as of the ImmutableProperties
semantics.Base exception for the configuration artifact.
Extension of the
ImmutableProperties type overwriting methods in
order to access the operating system's environment variables as of
env on Linux or Unix shells or set on Windows
machines (e.g."The
ImmutableProperties are a https://www.metacodes.proization of the
ImmutableTable.The interface
ImmutableProperties.MutableProperties defines "dirty" methods allowing
to modify ("mutate") the properties.Defines a meta-interface in order to retrieve properties from various
different properties sources (
ImmutableProperties instances) by
querying all the herein contained ImmutableProperties instances in
the order of them being added.The interface
ImmutablePropertiesPrecedence.MutablePropertiesPrecedence defines "dirty" methods
allowing to modify ("mutate") the ImmutablePropertiesPrecedence:
Add or remove ImmutableProperties inside a
ImmutablePropertiesPrecedence instance.Retrieve properties from various different properties sources
(
ImmutableProperties instances) by querying all the herein contained
ImmutableProperties instances in the order of them being added.The
ImmutableResourceProperties are a
https://www.metacodes.proization of the ImmutableTable.The interface
ImmutableResourceProperties.MutableResoureProperties defines "dirty" methods
allowing to modify ("mutate") the ImmutableResourceProperties.Factory interface for creating
ImmutableResourceProperties instances.The
ImmutableScheduledResourceProperties enrich
ImmutableResourceProperties with scheduling functionality whereby the
properties are being automatically reloaded periodically via
ImmutableResourceProperties.reload(ReloadMode).The interface
ImmutableScheduledResourceProperties.ScheduledMuableResourceProperties defines "dirty"
methods allowing to modify ("mutate") the
ImmutableScheduledResourceProperties.The
ImmutableScheduledResourcePropertiesDecorator decorates
ImmutableResourceProperties from which the properties are to be
reloaded periodically via AbstractImmutableResourcePropertiesDecorator.reload(ReloadMode).The
ImmutableStrictProperties type extends the
ImmutableProperties type with all the getters to throw a
KeyNotFoundRuntimeException instead of returning null in case the key
was not found.The Interface MutableStrictProperties.
The
ImmutableStrictPropertiesDecorator type decorates a
Properties instance with all the getters to throw a
KeyNotFoundRuntimeException instead of returning null in case the key
was not found.Implementation of the
ResourceProperties interface with support of so
called "Java properties" (or just "properties").The
JavaPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
JavaProperties.Implementation of the
ResourceProperties interface with support of so
called "JSON properties" (or just "properties").The
JsonPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
JsonProperties.The Class MapImmutableProperties.
Builder for collecting properties and creating
ImmutableProperties instances.The
NormalizedPropertiesDecorator type decorates a
ImmutableProperties instance and converts a path delimiter such as
the full-stop (".") to the ImmutableProperties properties' path
delimiter slash ("/", as of AbstractImmutablePropertiesDecorator.getDelimiter()).Implementation of the
ResourceProperties interface with support of so
called "PolyglotProperties" (or just "properties").The
PolyglotProperties.PolyglotPropertiesFactory is a meta factory using a
collection of ResourcePropertiesFactory instances to deliver
ResourceProperties instances.
The
ProfileProperties extend the ImmutableProperties with
runtime-profiles support.The
ProfilePropertiesDecorator type decorates an
ImmutableProperties instance and enriches it with runtime-profiles
support as of ProfileProperties.The
ProfilePropertiesProjection applies the runtime-profiles as of
ProfileProperties.getRuntimeProfiles() onto the encapsulated
ImmutableProperties (ProfileProperties) and provides a view
of them ImmutableProperties (ProfileProperties) from the
runtime-profiles' point of view e.g. as when runtime-profiles have been
applied to them ImmutableProperties (ProfileProperties).The interface
Properties defines builder functionality on top of the
properties .Provides an accessor for a
ImmutableProperties property.Provides a builder method for a
ImmutableProperties property
returning the builder for applying multiple build operations.Provides a mutator for a
ImmutableProperties property.Provides a
ImmutableProperties property.The currently known notations for
ImmutableResourceProperties
implementations.Provides an accessor for a
PropertiesNotation property.Provides a builder method for a
PropertiesNotation property
returning the builder for applying multiple build operations.Provides a mutator for a
PropertiesNotation property.Provides a
PropertiesNotation property.Enumeration representing defined path values.
The interface
ImmutablePropertiesPrecedence.MutablePropertiesPrecedence defines builder
functionality on top of the properties .The Class PropertiesPrecedenceComposite.
Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for the construction of
ImmutableProperties precedences using
ProfilePropertiesDecorator, ProfilePropertiesProjection,
ImmutableResourceProperties or
ImmutablePropertiesPrecedenceComposite (and the like).Mode of operation regarding the
ImmutableResourceProperties.reload(ReloadMode) method.The
ResourceConfigurable interface provides builder additions for
configuring the source of a properties origin with e.g.The interface
ResourceProperties defines builder functionality on top
of the ImmutableResourceProperties.MutableResoureProperties.Factory interface for creating
ResourceProperties instances.The interface
ScheduledResourceProperties defines builder
functionality on top of the ImmutableScheduledResourceProperties.ScheduledMuableResourceProperties.The
ScheduledResourcePropertiesDecorator decorates
ResourceProperties from which the properties are to be reloaded
periodically via AbstractResourcePropertiesDecorator.reload(ReloadMode).The
StrictProperties type extends the ImmutableStrictProperties.MutableStrictProperties
type with all the getters to throw a KeyNotFoundRuntimeException
instead of returning null in case the key was not found.The
StrictPropertiesDecorator type decorates a
ImmutableProperties instance with all the getters to throw a
KeyNotFoundRuntimeException instead of returning null in case the key
was not found.Extension of the
ImmutableProperties type overwriting methods in
order to access system properties as passed via the "-Dkey=value" when
launching the JVM (e.g.java -Dconsole.width=220) The keys are transformed to
a system properties by removing a prefixed "/" path delimiter (as of
ImmutableProperties.getDelimiter() and converting all other path delimiters "/" to the
system property's (de facto standard) separator ".".
Implementation of the
ResourceProperties interface with support of so
called "TOML properties".The
TomlPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
TomlProperties.The
UnmodifyableProperties decorates a Properties instance
for immutability (read only access).The
UnmodifyableResourceProperties decorates a Properties
instance for immutability (read only access).
Implementation of the
ResourceProperties interface with support of so
called "XML properties" (or just "properties").The
XmlPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
XmlProperties.Implementation of the
ResourceProperties interface with support of so
called "YAML properties" (or just "properties").The
YamlPropertiesFactory represents a
ResourcePropertiesFactory creating instances of type
YamlProperties.