Class EnvironmentProperties
java.lang.Object
org.refcodes.properties.EnvironmentProperties
- All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String, String>
Extension of the
ImmutableProperties type overwriting methods in
order to access the operating system's environment variables as of
env on Linux or Unix shells or set on Windows
machines (e.g."set JAVA_HOME=/opt/java9"). The keys are transformed to an
environment variable by removing a prefixed "/" path delimiter (as of
ImmutableProperties.getDelimiter() and converting all other path delimiters "/" to the
environment variable's (de facto standard) separator "_". If accessing
failed, then the upper case version of the so transformed key is probed.
Accessing an environment variable "JAVA_HOME" would be done with the path
"/java/home".-
Nested Class Summary
Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
Fields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface ImmutableProperties
DEFAULT_COMMENT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleancontainsKey(Object aKey) The key is transformed to an environment variable by removing a prefixed "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other path delimiters "/" to the environment variable's (de facto standard) separator "_".The key is transformed to an environment variable by removing a prefixed "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other path delimiters "/" to the environment variable's (de facto standard) separator "_".booleanisEmpty()keySet()The keys are transformed to a path by prefixing a "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other environment variable's (de facto standard) separators "_" to the path delimiter "/".retrieveFrom(String aFromPath) retrieveTo(String aToPath) intsize()toDataStructure(String aFromPath) values()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutableProperties
containsValue, getAnnotator, getDelimiter, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
Constructor Details
-
EnvironmentProperties
public EnvironmentProperties()
-
-
Method Details
-
containsKey
The key is transformed to an environment variable by removing a prefixed "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other path delimiters "/" to the environment variable's (de facto standard) separator "_". If accessing failed, then the upper case version of the so transformed key is probed.- Specified by:
containsKeyin interfaceKeys<String,String>
-
get
The key is transformed to an environment variable by removing a prefixed "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other path delimiters "/" to the environment variable's (de facto standard) separator "_". If accessing failed, then the upper case version of the so transformed key is probed. -
isEmpty
public boolean isEmpty()- Specified by:
isEmptyin interfaceEmptyAccessor
-
keySet
The keys are transformed to a path by prefixing a "/" path delimiter (as ofImmutableProperties.getDelimiter()and converting all other environment variable's (de facto standard) separators "_" to the path delimiter "/". -
retrieveFrom
- Specified by:
retrieveFromin interfaceImmutableCanonicalTable- Specified by:
retrieveFromin interfaceImmutablePathTable<String>- Specified by:
retrieveFromin interfaceImmutableProperties
-
retrieveTo
- Specified by:
retrieveToin interfaceImmutableCanonicalTable- Specified by:
retrieveToin interfaceImmutablePathTable<String>- Specified by:
retrieveToin interfaceImmutableProperties
-
size
public int size()- Specified by:
sizein interfaceContainable
-
toDataStructure
- Specified by:
toDataStructurein interfaceImmutablePathTable<String>
-
values
-