Interface ImmutableResourcePropertiesFactory

All Superinterfaces:
org.refcodes.mixin.FilenameSuffixesAccessor
All Known Subinterfaces:
ResourcePropertiesFactory
All Known Implementing Classes:
JavaPropertiesFactory, JsonPropertiesFactory, PolyglotProperties.PolyglotPropertiesFactory, TomlPropertiesFactory, XmlPropertiesFactory, YamlPropertiesFactory

public interface ImmutableResourcePropertiesFactory extends org.refcodes.mixin.FilenameSuffixesAccessor
Factory interface for creating ImmutableResourceProperties instances.
  • Method Details

    • hasFilenameSuffix

      default boolean hasFilenameSuffix(File aFile)
      Determines whether this factory may be responsible for a given file.
      Parameters:
      aFile - The file which's suffix is to be tested.
      Returns:
      True in case this factory may be responsible, else false.
    • hasFilenameSuffix

      default boolean hasFilenameSuffix(String aFilePath)
      Determines whether this factory may be responsible for a given file.
      Parameters:
      aFilePath - The path of the file which's suffix is to be tested.
      Returns:
      True in case this factory may be responsible, else false.
    • toProperties

      default ImmutableResourceProperties toProperties(Class<?> aResourceClass, String aFilePath) throws IOException, ParseException
      Loads the properties from the given file's path.
      Parameters:
      aResourceClass - The class which's class loader is to take care of loading the properties (from inside a JAR).
      aFilePath - The file path of the class's resources from which to load the properties.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      ImmutableResourceProperties toProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
      Loads the properties from the given file's path. A provided ConfigLocator describes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).
      Parameters:
      aResourceClass - The class which's class loader is to take care of loading the properties (from inside a JAR).
      aFilePath - The file path of the class's resources from which to load the properties.
      aConfigLocator - The ConfigLocator describes the locations to additional crawl for the desired file.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      default ImmutableResourceProperties toProperties(File aFile) throws IOException, ParseException
      Loads the properties from the given File.
      Parameters:
      aFile - The File from which to load the properties.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      ImmutableResourceProperties toProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
      Loads or seeks the properties from the given File. A provided ConfigLocator describes the locations to additional crawl for the desired file.
      Parameters:
      aFile - The File from which to load the properties.
      aConfigLocator - The ConfigLocator describes the locations to additional crawl for the desired file.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      Reads the properties from the given InputStream.
      Parameters:
      aInputStream - The InputStream from which to read the properties.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      ImmutableResourceProperties toProperties(Map<?,?> aProperties)
      Create a ImmutableResourceProperties instance containing the elements of the provided Map instance using the path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aProperties - the properties to be added.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
    • toProperties

      ImmutableResourceProperties toProperties(Object aObj)
      Create a ImmutableResourceProperties instance containing the elements as of ImmutablePathTable.MutablePathTable.insert(Object) using the path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of type Map, Collection and arrays are identified and handled as of their type: The path for each value in a Map is appended with its according key. The path for each value in a Collection or array is appended with its according index of occurrence (in case of a List or an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."
      Parameters:
      aObj - The object from which the elements are to be added.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
    • toProperties

      Create a ImmutableResourceProperties instance containing the elements of the provided ImmutableProperties instance using the path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aProperties - the properties to be added.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
    • toProperties

      ImmutableResourceProperties toProperties(Properties aProperties)
      Create a ImmutableResourceProperties instance containing the elements of the provided Properties instance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.
      Parameters:
      aProperties - the properties to be added.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
    • toProperties

      default ImmutableResourceProperties toProperties(String aFilePath) throws IOException, ParseException
      Loads the properties from the given file's path.
      Parameters:
      aFilePath - The path to the file from which to load the properties.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      default ImmutableResourceProperties toProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
      Loads the properties from the given file's path. A provided ConfigLocator describes the locations to additional crawl for the desired file.
      Parameters:
      aFilePath - The path to the file from which to load the properties.
      aConfigLocator - The ConfigLocator describes the locations to additional crawl for the desired file.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.
    • toProperties

      Loads the properties from the given URL.
      Parameters:
      aUrl - The URL from which to read the properties.
      Returns:
      The accordingly constructed ImmutableResourceProperties.
      Throws:
      IOException - thrown in case accessing or processing the properties file failed.
      ParseException - Signals that an error has been reached unexpectedly while parsing the data to be loaded.