- java.lang.Object
-
- org.refcodes.properties.AbstractResourceProperties
-
- org.refcodes.properties.JavaProperties
-
- All Implemented Interfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.TypeAccessor<String>,Properties,ResourceProperties,org.refcodes.struct.CanonicalMap,org.refcodes.struct.Containable,org.refcodes.struct.Dictionary<String,String>,org.refcodes.struct.InterOperableMap<String>,org.refcodes.struct.Keys<String,String>,org.refcodes.struct.PathMap<String>
public class JavaProperties extends AbstractResourceProperties implements ResourceProperties
Implementation of theResourcePropertiesinterface with support of so called "Java properties" (or just "properties"). For Java properties, see "https://en.wikipedia.org/wiki/.properties".
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classJavaProperties.JavaPropertiesFactoryTheJavaProperties.JavaPropertiesFactoryrepresents aResourcePropertiesFactorycreating instances of typeJavaProperties.-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder, org.refcodes.struct.CanonicalMap.MutableCanonicalMap
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
org.refcodes.struct.Dictionary.MutableDictionary<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyProperty
-
Nested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<T extends Object>, org.refcodes.struct.InterOperableMap.MutableInterOperableMap<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K extends Object,V extends Object>, org.refcodes.struct.Keys.MutableValues<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
org.refcodes.struct.PathMap.MutablePathMap<T extends Object>, org.refcodes.struct.PathMap.PathMapBuilder<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.properties.Properties
Properties.MutableProperties, Properties.PropertiesBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.properties.ResourceProperties
ResourceProperties.MutableResoureProperties, ResourceProperties.ResourcePropertiesBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.properties.AbstractResourceProperties
_properties
-
Fields inherited from interface org.refcodes.properties.Properties
DEFAULT_COMMENT
-
-
Constructor Summary
Constructors Constructor Description JavaProperties(File aFile)Loads the Java properties from the givenFile.JavaProperties(File aFile, char... aDelimiters)Loads the Java properties from the givenFile.JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads or seeks the Java properties from the givenFile.JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads or seeks the Java properties from the givenFile.JavaProperties(InputStream aInputStream)Reads the Java properties from the givenInputStream.JavaProperties(InputStream aInputStream, char... aDelimiters)Reads the Java properties from the givenInputStream.JavaProperties(Class<?> aResourceClass, String aFilePath)Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, char... aDelimiters)Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the Java properties from the given file's path.JavaProperties(Object aObj)Create aJavaPropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.JavaProperties(String aFilePath)Loads the Java properties from the given file's path.JavaProperties(String aFilePath, char... aDelimiters)Loads the Java properties from the given file's path.JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator)Loads the Java properties from the given file's path.JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters)Loads the Java properties from the given file's path.JavaProperties(URL aUrl)Loads the Java properties from the givenURL.JavaProperties(URL aUrl, char... aDelimiters)Loads the Java properties from the givenURL.JavaProperties(Map<?,?> aProperties)Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarationsJavaProperties(Properties aProperties)Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarationsJavaProperties(Properties.PropertiesBuilder aProperties)Create aJavaPropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleancontainsKey(Object aKey)Stringget(Object aKey)chargetDelimiter()Returns the default path delimiter as ofDelimiter.PATH.Class<String>getType()booleanisEmpty()Set<String>keySet()Propertiesreload()Reloads theResourcePropertiesfrom the resource to which theResourcePropertiesare attached to (such as aFileas ofResourceProperties.MutableResoureProperties.loadFrom(File)orResourceProperties.MutableResoureProperties.saveTo(File)).Propertiesreload(ReloadMode aReloadMode)Reloads theResourcePropertiesfrom the resource to which theResourcePropertiesare attached to (such as aFileas ofResourceProperties.MutableResoureProperties.loadFrom(File)orResourceProperties.MutableResoureProperties.saveTo(File)).PropertiesretrieveFrom(String aFromPath)PropertiesretrieveTo(String aToPath)intsize()ObjecttoDataStructure(String aFromPath)Collection<String>values()-
Methods inherited from class org.refcodes.properties.AbstractResourceProperties
toSerialized, toSerialized
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toProperties
-
Methods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOr
-
Methods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toType
-
Methods inherited from interface org.refcodes.properties.Properties
containsValue, getAnnotator, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
Methods inherited from interface org.refcodes.properties.ResourceProperties
toSerialized, toSerialized, toSerialized, toSerialized
-
-
-
-
Constructor Detail
-
JavaProperties
public JavaProperties(Object aObj)
Create aJavaPropertiesinstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.
-
JavaProperties
public JavaProperties(Properties aProperties)
Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.
-
JavaProperties
public JavaProperties(Properties.PropertiesBuilder aProperties)
Create aJavaPropertiesinstance containing the elements of the providedProperties.PropertiesBuilderinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.
-
JavaProperties
public JavaProperties(Map<?,?> aProperties)
Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations- Parameters:
aProperties- the properties to be added.
-
JavaProperties
public JavaProperties(File aFile) throws IOException, ParseException
Loads the Java properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads or seeks the Java properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads or seeks the Java properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath) throws IOException, ParseException
Loads the Java properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath) throws IOException, ParseException
Loads the Java properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException
Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(URL aUrl) throws IOException, ParseException
Loads the Java properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(URL aUrl, char... aDelimiters) throws IOException, ParseException
Loads the Java properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(InputStream aInputStream) throws IOException, ParseException
Reads the Java properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(InputStream aInputStream, char... aDelimiters) throws IOException, ParseException
Reads the Java properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.aDelimiters- The path delimiters to be used when parsing the source's properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
-
Method Detail
-
containsKey
public boolean containsKey(Object aKey)
-
values
public Collection<String> values()
-
size
public int size()
- Specified by:
sizein interfaceorg.refcodes.struct.Containable
-
isEmpty
public boolean isEmpty()
- Specified by:
isEmptyin interfaceorg.refcodes.mixin.EmptyAccessor
-
retrieveFrom
public Properties retrieveFrom(String aFromPath)
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>- Specified by:
retrieveFromin interfaceProperties
-
retrieveTo
public Properties retrieveTo(String aToPath)
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>- Specified by:
retrieveToin interfaceProperties
-
getDelimiter
public char getDelimiter()
Returns the default path delimiter as ofDelimiter.PATH.- Specified by:
getDelimiterin interfaceorg.refcodes.mixin.DelimiterAccessor- Specified by:
getDelimiterin interfaceProperties
-
getType
public Class<String> getType()
- Specified by:
getTypein interfaceProperties- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<String>
-
toDataStructure
public Object toDataStructure(String aFromPath)
- Specified by:
toDataStructurein interfaceorg.refcodes.struct.PathMap<String>
-
reload
public Properties reload() throws IOException, IllegalStateException, ParseException
Reloads theResourcePropertiesfrom the resource to which theResourcePropertiesare attached to (such as aFileas ofResourceProperties.MutableResoureProperties.loadFrom(File)orResourceProperties.MutableResoureProperties.saveTo(File)). In case the resource (such as anInputStream) does not support reloading, then anIllegalStateExceptionis thrown. Properties existing in the attached resource as well in thePropertiesitself are replaced. Properties existing in the attached resource but not(!) in thePropertiesitself are not(!) removed. UseResourceProperties.reload(ReloadMode)with an argument oftrue(~ orphan removal) to remove properties not existing in the resource.- Specified by:
reloadin interfaceResourceProperties- Returns:
- The
Propertiesas loaded from the resource and applied to this instance. - Throws:
IOException- thrown in case accessing the resource encountered an I/O problem.IllegalStateException- in case the attached resource does not support reloading.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
reload
public Properties reload(ReloadMode aReloadMode) throws IOException, IllegalStateException, ParseException
Reloads theResourcePropertiesfrom the resource to which theResourcePropertiesare attached to (such as aFileas ofResourceProperties.MutableResoureProperties.loadFrom(File)orResourceProperties.MutableResoureProperties.saveTo(File)). In case the resource (such as anInputStream) does not support reloading, then anIllegalStateExceptionis thrown. Properties existing in the attached resource as well in thePropertiesitself are replaced. When "orphan removal" is set tofalse, then properties existing in the attached resource but not(!) in thePropertiesitself are not(!) removed. When "orphan removal" is set totrue, then properties existing in the attached resource but not(!) in thePropertiesitself are(!) removed.- Specified by:
reloadin interfaceResourceProperties- Parameters:
aReloadMode- when set toReloadMode.ORPHAN_REMOVAL, then properties existing in the attached resource but not(!) in thePropertiesitself are(!) removed. Else properties not existing in the attached resource are kept.- Returns:
- The
Propertiesas loaded from the resource and applied to this instance. - Throws:
IOException- thrown in case accessing the resource encountered an I/O problem.IllegalStateException- in case the attached resource does not support reloading.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
-