Class JavaProperties
java.lang.Object
org.refcodes.struct.MapPathTable<String>
org.refcodes.struct.MapCanonicalTable
org.refcodes.properties.MapProperties
org.refcodes.properties.AbstractResourceProperties
org.refcodes.properties.JavaProperties
- All Implemented Interfaces:
Flushable,Serializable,Map<String,,String> org.refcodes.component.Flushable,org.refcodes.component.Flushable.FlushBuilder<ResourceProperties>,org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.Clearable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.TypeAccessor<String>,ImmutableProperties,ImmutableProperties.MutableProperties,ImmutableResourceProperties,ImmutableResourceProperties.MutableResoureProperties,Properties,ResourceProperties,org.refcodes.struct.CanonicalTable,org.refcodes.struct.Containable,org.refcodes.struct.ImmutableCanonicalTable,org.refcodes.struct.ImmutableCanonicalTable.MutableCanonicalTable,org.refcodes.struct.ImmutableInterOperableTable<String>,org.refcodes.struct.ImmutableInterOperableTable.MutableInterOperableTable<String>,org.refcodes.struct.ImmutablePathTable<String>,org.refcodes.struct.ImmutablePathTable.MutablePathTable<String>,org.refcodes.struct.ImmutableTable<String,,String> org.refcodes.struct.ImmutableTable.MutableTable<String,,String> org.refcodes.struct.InterOperableTable<String>,org.refcodes.struct.Keys<String,,String> org.refcodes.struct.Keys.MutableKeys<String,,String> org.refcodes.struct.Keys.MutableValues<String,,String> org.refcodes.struct.PathTable<String>,org.refcodes.struct.Table<String,String, org.refcodes.struct.PathTable<String>>
Implementation of the
ResourceProperties interface with support of so
called "Java properties" (or just "properties"). For Java properties, see
"https://en.wikipedia.org/wiki/.properties".- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.component.Flushable
org.refcodes.component.Flushable.FlushBuilder<B extends org.refcodes.component.Flushable.FlushBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutableCanonicalTable
org.refcodes.struct.ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableInterOperableTable
org.refcodes.struct.ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutablePathTable
org.refcodes.struct.ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface org.refcodes.properties.ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface org.refcodes.properties.ImmutableResourceProperties
ImmutableResourceProperties.MutableResourePropertiesNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable
org.refcodes.struct.ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K,V>, org.refcodes.struct.Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Field Summary
Fields inherited from class org.refcodes.properties.AbstractResourceProperties
_documentMetrics, _propertiesFileFields inherited from class org.refcodes.struct.MapPathTable
_backingMapFields inherited from interface org.refcodes.struct.ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface org.refcodes.properties.ImmutableProperties
DEFAULT_COMMENTFields inherited from interface org.refcodes.properties.ImmutableResourceProperties.MutableResoureProperties
DEFAULT_COMMENT -
Constructor Summary
ConstructorsConstructorDescriptionCreate an emptyJavaPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(File aFile) Loads the Java properties from the givenFile.JavaProperties(File aFile, DocumentMetrics aDocumentMetrics) Loads the Java properties from the givenFile.JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) Loads or seeks the Java properties from the givenFile.JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) Loads or seeks the Java properties from the givenFile.JavaProperties(InputStream aInputStream) Reads the Java properties from the givenInputStream.JavaProperties(InputStream aInputStream, DocumentMetrics aDocumentMetrics) Reads the Java properties from the givenInputStream.JavaProperties(Class<?> aResourceClass, String aFilePath) Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, DocumentMetrics aDocumentMetrics) Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) Loads the Java properties from the given file's path.JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) Loads the Java properties from the given file's path.JavaProperties(Object aObj) Create aJavaPropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.JavaProperties(Object aObj, DocumentMetrics aDocumentMetrics) Create aJavaPropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.JavaProperties(String aFilePath) Loads the Java properties from the given file's path.JavaProperties(String aFilePath, DocumentMetrics aDocumentMetrics) Loads the Java properties from the given file's path.JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) Loads the Java properties from the given file's path.JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) Loads the Java properties from the given file's path.JavaProperties(URL aUrl) Loads the Java properties from the givenURL.JavaProperties(URL aUrl, DocumentMetrics aDocumentMetrics) Loads the Java properties from the givenURL.JavaProperties(Map<?, ?> aProperties) Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(Map<?, ?> aProperties, DocumentMetrics aDocumentMetrics) Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(ImmutableProperties aProperties) Create aJavaPropertiesinstance containing the elements of the providedImmutablePropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(ImmutableProperties aProperties, DocumentMetrics aDocumentMetrics) /** Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(Properties aProperties) Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.JavaProperties(Properties aProperties, DocumentMetrics aDocumentMetrics) Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
Method Summary
Modifier and TypeMethodDescriptionprotected org.refcodes.struct.ext.factory.CanonicalTableFactoryAbstract method to be implemented by the sub-classes returning the concreteCanonicalTableFactoryresponsible to fabricate theImmutableCanonicalTableinstances as of the required notation.Methods inherited from class org.refcodes.properties.AbstractResourceProperties
flush, isFlushable, loadFrom, loadFrom, reload, reload, saveTo, saveTo, seekFrom, withInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPut, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutByte, withPutByte, withPutByte, withPutByte, withPutByte, withPutChar, withPutChar, withPutChar, withPutChar, withPutChar, withPutClass, withPutClass, withPutClass, withPutClass, withPutClass, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutInt, withPutInt, withPutInt, withPutInt, withPutInt, withPutLong, withPutLong, withPutLong, withPutLong, withPutLong, withPutShort, withPutShort, withPutShort, withPutShort, withPutShort, withPutString, withPutString, withPutString, withPutString, withPutString, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathsMethods inherited from class org.refcodes.properties.MapProperties
retrieveFrom, retrieveToMethods inherited from class org.refcodes.struct.MapCanonicalTable
fromInstance, fromObject, toInstanceMethods inherited from class org.refcodes.struct.MapPathTable
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toString, toType, valuesMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.component.Flushable
flushUncheckedMethods inherited from interface org.refcodes.component.Flushable.FlushBuilder
withFlush, withFlushUncheckedMethods inherited from interface org.refcodes.struct.ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface org.refcodes.struct.ImmutableCanonicalTable.MutableCanonicalTable
containsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, putAll, removeFromMethods inherited from interface org.refcodes.struct.ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface org.refcodes.struct.ImmutableInterOperableTable.MutableInterOperableTable
containsValue, insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringMethods inherited from interface org.refcodes.struct.ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface org.refcodes.struct.ImmutablePathTable.MutablePathTable
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface org.refcodes.properties.ImmutableProperties
getAnnotator, getDelimiter, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, retrieveToMethods inherited from interface org.refcodes.properties.ImmutableProperties.MutableProperties
containsValue, delete, insert, insert, insertBetween, insertFrom, insertTo, put, putAll, putAll, putAll, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePathsMethods inherited from interface org.refcodes.properties.ImmutableResourceProperties
toSerialized, toSerialized, toSerializedMethods inherited from interface org.refcodes.properties.ImmutableResourceProperties.MutableResoureProperties
fileTo, fileTo, fileTo, fileTo, fileTo, fileTo, fileTo, fileTo, loadFrom, loadFrom, loadFrom, parseFrom, saveTo, saveTo, saveTo, saveTo, saveTo, saveTo, saveTo, saveTo, saveTo, saveTo, seekFrom, seekFrom, seekFrom, seekFrom, seekFrom, toSerializedMethods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableValues
putMethods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface org.refcodes.properties.ResourceProperties
withLoadFrom, withLoadFrom, withLoadFrom, withLoadFrom, withLoadFrom, withSeekFrom, withSeekFrom, withSeekFrom
-
Constructor Details
-
JavaProperties
public JavaProperties()Create an emptyJavaPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
JavaProperties
Loads the Java properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the given file's path.- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed).- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(Class<?> aResourceClass, String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file. Finally (if nothing else succeeds) the properties are loaded by the provided class's class loader which takes care of loading the properties (in case the file path is a relative path, also the absolute path with a prefixed path delimiter "/" is probed). *- Parameters:
aResourceClass- The class which's class loader is to take care of loading the properties (from inside a JAR).aFilePath- The file path of the class's resources from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
Loads the Java properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the givenFile.- Parameters:
aFile- TheFilefrom which to load the properties.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException Loads or seeks the Java properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(File aFile, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads or seeks the Java properties from the givenFile. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFile- TheFilefrom which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
Reads the Java properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(InputStream aInputStream, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Reads the Java properties from the givenInputStream.- Parameters:
aInputStream- TheInputStreamfrom which to read the properties.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
JavaProperties
Create aJavaPropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).
-
JavaProperties
Create aJavaPropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.
-
JavaProperties
Create aJavaPropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).
-
JavaProperties
Create aJavaPropertiesinstance containing the elements of the providedImmutablePropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
JavaProperties
/** Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).
-
JavaProperties
Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
JavaProperties
Create aJavaPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).
-
JavaProperties
Loads the Java properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the given file's path.- Parameters:
aFilePath- The path to the file from which to load the properties.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator) throws IOException, ParseException Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(String aFilePath, org.refcodes.runtime.ConfigLocator aConfigLocator, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the given file's path. A providedConfigLocatordescribes the locations to additional crawl for the desired file.- Parameters:
aFilePath- The path to the file from which to load the properties.aConfigLocator- TheConfigLocatordescribes the locations to additional crawl for the desired file.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
Loads the Java properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
JavaProperties
public JavaProperties(URL aUrl, DocumentMetrics aDocumentMetrics) throws IOException, ParseException Loads the Java properties from the givenURL.- Parameters:
aUrl- TheURLfrom which to read the properties.aDocumentMetrics- Provides various metrics which may be tweaked when marshaling or unmarshaling documents of various nations (such as INI, XML, YAML, JSON, TOML, PROPERTIES, etc.).- Throws:
IOException- thrown in case accessing or processing the properties file failed.ParseException- Signals that an error has been reached unexpectedly while parsing the data to be loaded.
-
-
Method Details
-
createCanonicalMapFactory
protected org.refcodes.struct.ext.factory.CanonicalTableFactory createCanonicalMapFactory()Abstract method to be implemented by the sub-classes returning the concreteCanonicalTableFactoryresponsible to fabricate theImmutableCanonicalTableinstances as of the required notation.- Specified by:
createCanonicalMapFactoryin classAbstractResourceProperties- Returns:
- The
CanonicalTableFactorysupporting the required notation.
-