Class MapImmutableProperties
java.lang.Object
org.refcodes.properties.MapImmutableProperties
- All Implemented Interfaces:
org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.TypeAccessor<String>,ImmutableProperties,org.refcodes.struct.Containable,org.refcodes.struct.ImmutableCanonicalTable,org.refcodes.struct.ImmutableInterOperableTable<String>,org.refcodes.struct.ImmutablePathTable<String>,org.refcodes.struct.ImmutableTable<String,,String> org.refcodes.struct.Keys<String,String>
- Direct Known Subclasses:
ArgsProperties
The Class MapImmutableProperties.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classBuilder for collecting properties and creatingImmutablePropertiesinstances.Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B extends org.refcodes.mixin.EmptyAccessor.EmptyBuilder<B>>, org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableCanonicalTable
org.refcodes.struct.ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableInterOperableTable
org.refcodes.struct.ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface org.refcodes.struct.ImmutablePathTable
org.refcodes.struct.ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface org.refcodes.properties.ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface org.refcodes.struct.ImmutableTable
org.refcodes.struct.ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K,V>, org.refcodes.struct.Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> -
Field Summary
FieldsFields inherited from interface org.refcodes.struct.ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface org.refcodes.properties.ImmutableProperties
DEFAULT_COMMENT -
Constructor Summary
ConstructorsConstructorDescriptionCreates an empty immutableImmutablePropertiesobject.MapImmutableProperties(Object aObj) Create aImmutablePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object.MapImmutableProperties(Map<?, ?> aProperties) Create aImmutablePropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapImmutableProperties(Properties aProperties) Create aPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.MapImmutableProperties(org.refcodes.struct.Property... aProperties) Create aImmutablePropertiesinstance containing the providedPropertyinstances' key/value-pairs. -
Method Summary
Modifier and TypeMethodDescriptionbuilder()Creates a newMapImmutableProperties.Builderfor constructingImmutablePropertiesinstances.booleancontainsKey(Object aKey) booleancharReturns the default path delimiter as ofDelimiter.PATH.getType()inthashCode()booleanisEmpty()keySet()retrieveFrom(String aFromPath) retrieveTo(String aToPath) intsize()toDataStructure(String aFromPath) values()Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.struct.ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface org.refcodes.struct.ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface org.refcodes.struct.ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface org.refcodes.properties.ImmutableProperties
containsValue, getAnnotator, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveToMethods inherited from interface org.refcodes.struct.Keys
getOr, use
-
Field Details
-
_properties
-
-
Constructor Details
-
MapImmutableProperties
public MapImmutableProperties()Creates an empty immutableImmutablePropertiesobject. -
MapImmutableProperties
Create aImmutablePropertiesinstance containing the elements of the providedMapinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
MapImmutableProperties
Create aImmutablePropertiesinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations: "Inspects the given object and adds all elements found in the given object. Elements of typeMap,Collectionand arrays are identified and handled as of their type: The path for each value in aMapis appended with its according key. The path for each value in aCollectionor array is appended with its according index of occurrence (in case of aListor an array, its actual index). In case of reflection, the path for each member is appended with its according mamber's name. All elements (e.g. the members and values) are inspected recursively which results in the according paths of the terminating values."- Parameters:
aObj- The object from which the elements are to be added.
-
MapImmutableProperties
Create aPropertiesinstance containing the elements of the providedPropertiesinstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aProperties- the properties to be added.
-
MapImmutableProperties
public MapImmutableProperties(org.refcodes.struct.Property... aProperties) Create aImmutablePropertiesinstance containing the providedPropertyinstances' key/value-pairs.- Parameters:
aProperties- the properties to be added.
-
-
Method Details
-
containsKey
-
equals
-
get
-
getDelimiter
public char getDelimiter()Returns the default path delimiter as ofDelimiter.PATH.- Specified by:
getDelimiterin interfaceorg.refcodes.mixin.DelimiterAccessor- Specified by:
getDelimiterin interfaceImmutableProperties
-
getType
- Specified by:
getTypein interfaceImmutableProperties- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<String>
-
hashCode
-
isEmpty
public boolean isEmpty()- Specified by:
isEmptyin interfaceorg.refcodes.mixin.EmptyAccessor
-
keySet
-
retrieveFrom
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.ImmutableCanonicalTable- Specified by:
retrieveFromin interfaceorg.refcodes.struct.ImmutablePathTable<String>- Specified by:
retrieveFromin interfaceImmutableProperties
-
retrieveTo
- Specified by:
retrieveToin interfaceorg.refcodes.struct.ImmutableCanonicalTable- Specified by:
retrieveToin interfaceorg.refcodes.struct.ImmutablePathTable<String>- Specified by:
retrieveToin interfaceImmutableProperties
-
size
public int size()- Specified by:
sizein interfaceorg.refcodes.struct.Containable
-
toDataStructure
-
values
-
builder
Creates a newMapImmutableProperties.Builderfor constructingImmutablePropertiesinstances.- Returns:
- A new builder instance
-