Class ProfilePropertiesProjection
java.lang.Object
org.refcodes.properties.ProfilePropertiesProjection
- All Implemented Interfaces:
AnnotatorAccessor, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, ImmutableProperties, Containable, ImmutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutableTable<String,String>, Keys<String, String>
The
ProfilePropertiesProjection applies the runtime-profiles as of
ProfileProperties.getRuntimeProfiles() onto the encapsulated
ImmutableProperties (ProfileProperties) and provides a view
of them ImmutableProperties (ProfileProperties) from the
runtime-profiles' point of view e.g. as when runtime-profiles have been
applied to them ImmutableProperties (ProfileProperties). In
other words, the runtime-profiles are resolved and the result is provided as
view: Under the hood, the provided ImmutableProperties are decorated
with a ProfilePropertiesDecorator which then is used to provide the
profile projection via ProfileProperties.toRuntimeProfile().-
Nested Class Summary
Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableProperties
ImmutableProperties.MutablePropertiesNested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
Fields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITERFields inherited from interface ImmutableProperties
DEFAULT_COMMENT -
Constructor Summary
ConstructorsConstructorDescriptionProfilePropertiesProjection(ImmutableProperties aProperties, String... aProfiles) Wraps theImmutablePropertieswith a profile projection.ProfilePropertiesProjection(ProfileProperties aProperties) Uses theProfilePropertiesfor the profile projection.ProfilePropertiesProjection(ProfileProperties aProperties, String... aProfiles) Uses theProfilePropertiesfor the profile projection.ProfilePropertiesProjection(Properties aProperties, String... aProfiles) Wraps thePropertieswith a profile projection. -
Method Summary
Modifier and TypeMethodDescriptionbooleancontainsKey(Object aKey) charReturns the default path delimiter as ofDelimiter.PATH.booleanisEmpty()keySet()retrieveFrom(String aFromPath) retrieveTo(String aToPath) intsize()toDataStructure(String aFromPath) values()Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, queryBetween, toMap, toPropertiesMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutableProperties
containsValue, getAnnotator, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, getType, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo
-
Constructor Details
-
ProfilePropertiesProjection
Uses theProfilePropertiesfor the profile projection. TheProfilePropertiesprovide the profile projection viaProfileProperties.toRuntimeProfile().- Parameters:
aProperties- The properties which provide the according profile projections applying the therein set runtime-profiles. The evaluation is done as ofProfileProperties.toRuntimeProfile(String...).
-
ProfilePropertiesProjection
Uses theProfilePropertiesfor the profile projection. TheProfilePropertiesprovide the profile projection viaProfileProperties.toRuntimeProfile(String...)using the provided runtime-profiles- Parameters:
aProperties- The properties which are to be projected according to the therein set runtime-profiles. The evaluation is done as ofProfileProperties.toRuntimeProfile(String...).aProfiles- The runtime-profiles to be used when constructing the projection.
-
ProfilePropertiesProjection
Wraps theImmutablePropertieswith a profile projection. TheImmutablePropertiesare decorated with aProfilePropertiesDecoratorwhich provides the projectedImmutablePropertiesfrom the wrappedImmutablePropertieswith the given runtime-profiles applied. See alsoProfileProperties.toRuntimeProfile(String...).- Parameters:
aProperties- The properties which are to be projected according to the provided runtime-profiles. The evaluation is done as ofProfileProperties.toRuntimeProfile(String...).aProfiles- The runtime-profiles to be used when constructing the projection.
-
ProfilePropertiesProjection
Wraps thePropertieswith a profile projection. ThePropertiesare decorated with aProfilePropertiesDecoratorwhich then is used to provide the profile projection viaProfileProperties.toRuntimeProfile(String...)using the provided runtime-profiles- Parameters:
aProperties- The properties which are to be projected according to the therein set runtime-profiles. The evaluation is done as ofProfileProperties.toRuntimeProfile(String...).aProfiles- The runtime-profiles to be used when constructing the projection.
-
-
Method Details
-
containsKey
- Specified by:
containsKeyin interfaceKeys<String,String>
-
get
-
getDelimiter
public char getDelimiter()Returns the default path delimiter as ofDelimiter.PATH.- Specified by:
getDelimiterin interfaceDelimiterAccessor- Specified by:
getDelimiterin interfaceImmutableProperties
-
isEmpty
public boolean isEmpty()- Specified by:
isEmptyin interfaceEmptyAccessor
-
keySet
-
retrieveFrom
- Specified by:
retrieveFromin interfaceImmutableCanonicalTable- Specified by:
retrieveFromin interfaceImmutablePathTable<String>- Specified by:
retrieveFromin interfaceImmutableProperties
-
retrieveTo
- Specified by:
retrieveToin interfaceImmutableCanonicalTable- Specified by:
retrieveToin interfaceImmutablePathTable<String>- Specified by:
retrieveToin interfaceImmutableProperties
-
size
public int size()- Specified by:
sizein interfaceContainable
-
toDataStructure
- Specified by:
toDataStructurein interfaceImmutablePathTable<String>
-
values
-