Uses of Class
org.refcodes.properties.PropertiesPath
-
-
Uses of PropertiesPath in org.refcodes.properties
Methods in org.refcodes.properties that return PropertiesPath Modifier and Type Method Description static PropertiesPathPropertiesPath. valueOf(String name)Returns the enum constant of this type with the specified name.static PropertiesPath[]PropertiesPath. values()Returns an array containing the constants of this enum type, in the order they are declared.
-